@@ -21,9 +21,10 @@
 #define CPL_ARRAY_H
 
 #include <stdio.h>
-#if ((defined(__STDC_IEC_559_COMPLEX__) || (__STDC_VERSION__ >= 199901L) || \
-      (__GNUC__ >= 3)) &&                                                   \
-     !defined(__cplusplus))
+#if (!defined(__cplusplus) &&                                         \
+     (defined(__STDC_IEC_559_COMPLEX__) ||                            \
+      (defined(__STDC_VERSION__) && (__STDC_VERSION__ >= 199901L)) || \
+      (__GNUC__ >= 3)))
 #include <complex.h>
 #endif
 #include <cpl_macros.h>
