@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@
                                    Define
  -----------------------------------------------------------------------------*/
 
-#define HALF_CENTROID_DOMAIN        5
+#define HALF_CENTROID_DOMAIN 5
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -66,9 +66,10 @@
                                    Type definition
  -----------------------------------------------------------------------------*/
 
-struct _cpl_bivector_ {
-    cpl_vector * x;
-    cpl_vector * y;
+struct _cpl_bivector_
+{
+    cpl_vector *x;
+    cpl_vector *y;
 };
 
 /*-----------------------------------------------------------------------------
@@ -89,9 +90,10 @@ struct _cpl_bivector_ {
   - CPL_ERROR_ILLEGAL_INPUT if n is < 1.
  */
 /*----------------------------------------------------------------------------*/
-cpl_bivector * cpl_bivector_new(cpl_size n)
+cpl_bivector *
+cpl_bivector_new(cpl_size n)
 {
-    cpl_bivector * f;
+    cpl_bivector *f;
 
     /* Test input */
     cpl_ensure(n > 0, CPL_ERROR_ILLEGAL_INPUT, NULL);
@@ -124,18 +126,17 @@ cpl_bivector * cpl_bivector_new(cpl_size n)
   - CPL_ERROR_ILLEGAL_INPUT if the input vectors have different sizes
  */
 /*----------------------------------------------------------------------------*/
-cpl_bivector * cpl_bivector_wrap_vectors(
-        cpl_vector    *   x,
-        cpl_vector    *   y)
+cpl_bivector *
+cpl_bivector_wrap_vectors(cpl_vector *x, cpl_vector *y)
 {
-    cpl_bivector    *   f;
+    cpl_bivector *f;
 
     /* Test input */
     cpl_ensure(x, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(y, CPL_ERROR_NULL_INPUT, NULL);
 
-    cpl_ensure(cpl_vector_get_size(x)==cpl_vector_get_size(y),
-            CPL_ERROR_ILLEGAL_INPUT, NULL);
+    cpl_ensure(cpl_vector_get_size(x) == cpl_vector_get_size(y),
+               CPL_ERROR_ILLEGAL_INPUT, NULL);
 
     /* Allocate memory */
     f = cpl_malloc(sizeof(cpl_bivector));
@@ -159,12 +160,13 @@ cpl_bivector * cpl_bivector_wrap_vectors(
     different sizes
  */
 /*----------------------------------------------------------------------------*/
-cpl_bivector * cpl_bivector_duplicate(const cpl_bivector * in)
+cpl_bivector *
+cpl_bivector_duplicate(const cpl_bivector *in)
 {
-    cpl_bivector    *   out;
+    cpl_bivector *out;
 
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
-    cpl_ensure(cpl_vector_get_size(in->x)==cpl_vector_get_size(in->y),
+    cpl_ensure(cpl_vector_get_size(in->x) == cpl_vector_get_size(in->y),
                CPL_ERROR_ILLEGAL_INPUT, NULL);
 
     out = cpl_malloc(sizeof(cpl_bivector));
@@ -186,14 +188,15 @@ cpl_bivector * cpl_bivector_duplicate(const cpl_bivector * in)
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
 */
 /*----------------------------------------------------------------------------*/
-cpl_error_code cpl_bivector_copy(cpl_bivector       * self,
-                                 const cpl_bivector * other)
+cpl_error_code
+cpl_bivector_copy(cpl_bivector *self, const cpl_bivector *other)
 {
     return cpl_vector_copy(cpl_bivector_get_x(self),
                            cpl_bivector_get_x_const(other)) ||
-        cpl_vector_copy(cpl_bivector_get_y(self),
-                        cpl_bivector_get_y_const(other))
-        ? cpl_error_set_where_() : CPL_ERROR_NONE;
+                   cpl_vector_copy(cpl_bivector_get_y(self),
+                                   cpl_bivector_get_y_const(other))
+               ? cpl_error_set_where_()
+               : CPL_ERROR_NONE;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -208,9 +211,11 @@ cpl_error_code cpl_bivector_copy(cpl_bivector       * self,
 
  */
 /*----------------------------------------------------------------------------*/
-void cpl_bivector_delete(cpl_bivector * f)
+void
+cpl_bivector_delete(cpl_bivector *f)
 {
-    if (f == NULL) return;
+    if (f == NULL)
+        return;
     cpl_vector_delete(f->x);
     cpl_vector_delete(f->y);
     cpl_free(f);
@@ -226,7 +231,8 @@ void cpl_bivector_delete(cpl_bivector * f)
 
  */
 /*----------------------------------------------------------------------------*/
-void cpl_bivector_unwrap_vectors(cpl_bivector * f)
+void
+cpl_bivector_unwrap_vectors(cpl_bivector *f)
 {
     cpl_free(f);
     return;
@@ -249,19 +255,22 @@ void cpl_bivector_unwrap_vectors(cpl_bivector * f)
     precision loss due to the limited accuracy of the ASCII representation.
  */
 /*----------------------------------------------------------------------------*/
-void cpl_bivector_dump(const cpl_bivector * f, FILE * stream)
+void
+cpl_bivector_dump(const cpl_bivector *f, FILE *stream)
 {
-    const double * data_x;
-    const double * data_y;
-    cpl_size       i;
+    const double *data_x;
+    const double *data_y;
+    cpl_size i;
 
-    if (stream == NULL) stream = stdout;
+    if (stream == NULL)
+        stream = stdout;
     if (f == NULL) {
         fprintf(stream, "#NULL bivector\n");
         return;
     }
 
-    if (cpl_vector_get_size(f->x) != cpl_vector_get_size(f->y)) return;
+    if (cpl_vector_get_size(f->x) != cpl_vector_get_size(f->y))
+        return;
 
     data_x = cpl_vector_get_data_const(f->x);
     data_y = cpl_vector_get_data_const(f->y);
@@ -297,21 +306,22 @@ void cpl_bivector_dump(const cpl_bivector * f, FILE * stream)
   - CPL_ERROR_BAD_FILE_FORMAT if the file contains no valid lines
  */
 /*----------------------------------------------------------------------------*/
-cpl_bivector * cpl_bivector_read(const char * filename)
+cpl_bivector *
+cpl_bivector_read(const char *filename)
 {
-    FILE        *   in;
-    cpl_vector  *   v1;
-    cpl_vector  *   v2;
-    cpl_size        np = 0;
-    cpl_size        size = 1000; /* Default size */
-    char            line[1024];
-    double          x, y;
+    FILE *in;
+    cpl_vector *v1;
+    cpl_vector *v2;
+    cpl_size np = 0;
+    cpl_size size = 1000; /* Default size */
+    char line[1024];
+    double x, y;
 
     cpl_ensure(filename, CPL_ERROR_NULL_INPUT, NULL);
 
     /* Open the file */
     in = fopen(filename, "r");
-    cpl_ensure(in,       CPL_ERROR_FILE_IO, NULL);
+    cpl_ensure(in, CPL_ERROR_FILE_IO, NULL);
 
     /* Create and fill the vectors */
     v1 = cpl_vector_new(size);
@@ -355,7 +365,6 @@ cpl_bivector * cpl_bivector_read(const char * filename)
 
     /* Cannot fail at this point */
     return cpl_bivector_wrap_vectors(v1, v2);
-
 }
 
 /*----------------------------------------------------------------------------*/
@@ -370,21 +379,20 @@ cpl_bivector * cpl_bivector_read(const char * filename)
     different sizes
  */
 /*----------------------------------------------------------------------------*/
-cpl_size cpl_bivector_get_size(const cpl_bivector * in)
+cpl_size
+cpl_bivector_get_size(const cpl_bivector *in)
 {
-
-    cpl_size     size;
+    cpl_size size;
 
 
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, -1);
 
-    assert( in->x );
-    assert( in->y );
+    assert(in->x);
+    assert(in->y);
 
     /* Get sizes of x and y vectors */
     size = cpl_vector_get_size(in->x);
-    cpl_ensure(size == cpl_vector_get_size(in->y), CPL_ERROR_ILLEGAL_INPUT,
-               -2);
+    cpl_ensure(size == cpl_vector_get_size(in->y), CPL_ERROR_ILLEGAL_INPUT, -2);
 
     return size;
 }
@@ -401,12 +409,12 @@ cpl_size cpl_bivector_get_size(const cpl_bivector * in)
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
  */
 /*----------------------------------------------------------------------------*/
-cpl_vector * cpl_bivector_get_x(cpl_bivector * in)
+cpl_vector *
+cpl_bivector_get_x(cpl_bivector *in)
 {
-
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->x );
+    assert(in->x);
 
     return in->x;
 }
@@ -419,11 +427,12 @@ cpl_vector * cpl_bivector_get_x(cpl_bivector * in)
   @see cpl_bivector_get_x
  */
 /*----------------------------------------------------------------------------*/
-const cpl_vector * cpl_bivector_get_x_const (const cpl_bivector * in)
+const cpl_vector *
+cpl_bivector_get_x_const(const cpl_bivector *in)
 {
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->x );
+    assert(in->x);
 
     return in->x;
 }
@@ -440,12 +449,12 @@ const cpl_vector * cpl_bivector_get_x_const (const cpl_bivector * in)
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
  */
 /*----------------------------------------------------------------------------*/
-cpl_vector * cpl_bivector_get_y(cpl_bivector * in)
+cpl_vector *
+cpl_bivector_get_y(cpl_bivector *in)
 {
-
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->y );
+    assert(in->y);
 
     return in->y;
 }
@@ -457,11 +466,12 @@ cpl_vector * cpl_bivector_get_y(cpl_bivector * in)
   @return   Pointer to the y vector or NULL on error
  */
 /*----------------------------------------------------------------------------*/
-const cpl_vector * cpl_bivector_get_y_const(const cpl_bivector * in)
+const cpl_vector *
+cpl_bivector_get_y_const(const cpl_bivector *in)
 {
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->y );
+    assert(in->y);
 
     return in->y;
 }
@@ -484,12 +494,12 @@ const cpl_vector * cpl_bivector_get_y_const(const cpl_bivector * in)
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
  */
 /*----------------------------------------------------------------------------*/
-double * cpl_bivector_get_x_data(cpl_bivector * in)
+double *
+cpl_bivector_get_x_data(cpl_bivector *in)
 {
-
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->x );
+    assert(in->x);
 
     return cpl_vector_get_data(in->x);
 }
@@ -503,11 +513,12 @@ double * cpl_bivector_get_x_data(cpl_bivector * in)
 
  */
 /*----------------------------------------------------------------------------*/
-const double * cpl_bivector_get_x_data_const(const cpl_bivector * in)
+const double *
+cpl_bivector_get_x_data_const(const cpl_bivector *in)
 {
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->x );
+    assert(in->x);
 
     return cpl_vector_get_data_const(in->x);
 }
@@ -523,12 +534,12 @@ const double * cpl_bivector_get_x_data_const(const cpl_bivector * in)
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
  */
 /*----------------------------------------------------------------------------*/
-double * cpl_bivector_get_y_data(cpl_bivector * in)
+double *
+cpl_bivector_get_y_data(cpl_bivector *in)
 {
-
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->y );
+    assert(in->y);
 
     return cpl_vector_get_data(in->y);
 }
@@ -541,11 +552,12 @@ double * cpl_bivector_get_y_data(cpl_bivector * in)
   @see cpl_bivector_get_y_data
  */
 /*----------------------------------------------------------------------------*/
-const double * cpl_bivector_get_y_data_const(const cpl_bivector * in)
+const double *
+cpl_bivector_get_y_data_const(const cpl_bivector *in)
 {
     cpl_ensure(in, CPL_ERROR_NULL_INPUT, NULL);
 
-    assert( in->y );
+    assert(in->y);
 
     return cpl_vector_get_data_const(in->y);
 }
@@ -582,29 +594,29 @@ const double * cpl_bivector_get_y_data_const(const cpl_bivector * in)
     abscissa vectors is not met.
  */
 /*----------------------------------------------------------------------------*/
-cpl_error_code cpl_bivector_interpolate_linear(cpl_bivector * fout,
-                                               const cpl_bivector * fref)
+cpl_error_code
+cpl_bivector_interpolate_linear(cpl_bivector *fout, const cpl_bivector *fref)
 {
-    const cpl_size m    = cpl_bivector_get_size(fref);
-    const cpl_size n    = cpl_bivector_get_size(fout);
-    const double * xref = cpl_bivector_get_x_data_const(fref);
-    const double * yref = cpl_bivector_get_y_data_const(fref);
-    double       * xout = cpl_bivector_get_x_data(fout);
-    double       * yout = cpl_bivector_get_y_data(fout);
+    const cpl_size m = cpl_bivector_get_size(fref);
+    const cpl_size n = cpl_bivector_get_size(fout);
+    const double *xref = cpl_bivector_get_x_data_const(fref);
+    const double *yref = cpl_bivector_get_y_data_const(fref);
+    double *xout = cpl_bivector_get_x_data(fout);
+    double *yout = cpl_bivector_get_y_data(fout);
 
     double grad = DBL_MAX; /* Avoid (false) uninit warning */
-    double y_0  = DBL_MAX; /* Avoid (false) uninit warning */
+    double y_0 = DBL_MAX;  /* Avoid (false) uninit warning */
     cpl_size ibelow, iabove;
     cpl_size i;
 
 
-    cpl_ensure_code( xref != NULL, cpl_error_get_code());
-    cpl_ensure_code( yref != NULL, cpl_error_get_code());
-    cpl_ensure_code( xout != NULL, cpl_error_get_code());
-    cpl_ensure_code( yout != NULL, cpl_error_get_code());
+    cpl_ensure_code(xref != NULL, cpl_error_get_code());
+    cpl_ensure_code(yref != NULL, cpl_error_get_code());
+    cpl_ensure_code(xout != NULL, cpl_error_get_code());
+    cpl_ensure_code(yout != NULL, cpl_error_get_code());
 
     /* Upper extrapolation not allowed */
-    cpl_ensure_code(xout[n-1] <= xref[m-1], CPL_ERROR_DATA_NOT_FOUND);
+    cpl_ensure_code(xout[n - 1] <= xref[m - 1], CPL_ERROR_DATA_NOT_FOUND);
 
     /* Start interpolation from below */
     ibelow = cpl_vector_find(cpl_bivector_get_x_const(fref), xout[0]);
@@ -623,28 +635,27 @@ cpl_error_code cpl_bivector_interpolate_linear(cpl_bivector * fout,
         /* When possible reuse reference function abscissa points */
         if (xref[iabove] < xout[i]) {
             /* No, need new points */
-            while (xref[++iabove] < xout[i]);
+            while (xref[++iabove] < xout[i])
+                ;
             ibelow = iabove - 1;
 
             /* Verify that the pair of reference abscissa points are valid */
-            if (xref[iabove] <= xref[ibelow]) break;
+            if (xref[iabove] <= xref[ibelow])
+                break;
 
-            grad = (yref[iabove] - yref[ibelow])
-                 / (xref[iabove] - xref[ibelow]);
+            grad =
+                (yref[iabove] - yref[ibelow]) / (xref[iabove] - xref[ibelow]);
 
-            y_0  = yref[ibelow] - grad * xref[ibelow];
+            y_0 = yref[ibelow] - grad * xref[ibelow];
         }
 
         if (xref[ibelow] < xout[i]) {
-
             yout[i] = y_0 + grad * xout[i];
-
-        } else {
-
+        }
+        else {
             /* assert( xout[i] == xref[ibelow] ); */
 
             yout[i] = yref[ibelow];
-
         }
     }
 
@@ -678,38 +689,40 @@ cpl_error_code cpl_bivector_interpolate_linear(cpl_bivector * fout,
                                CPL_SORT_BY_X nor CPL_SORT_BY_Y
  */
 /*----------------------------------------------------------------------------*/
-cpl_error_code cpl_bivector_sort(cpl_bivector * self,
-                                 const cpl_bivector * other,
-                                 cpl_sort_direction dir,
-                                 cpl_sort_mode mode)
+cpl_error_code
+cpl_bivector_sort(cpl_bivector *self,
+                  const cpl_bivector *other,
+                  cpl_sort_direction dir,
+                  cpl_sort_mode mode)
 {
-
     const cpl_size n = cpl_bivector_get_size(self);
-    cpl_ifalloc    permbuf; /* Avoid malloc() on small data sets */
-    cpl_size     * perm;
-    const double * data;
-    int            reverse;
-    cpl_size       i;
+    cpl_ifalloc permbuf; /* Avoid malloc() on small data sets */
+    cpl_size *perm;
+    const double *data;
+    int reverse;
+    cpl_size i;
     cpl_error_code error = CPL_ERROR_NONE;
 
 
-    cpl_ensure_code(self  != NULL, CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(self != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(other != NULL, CPL_ERROR_NULL_INPUT);
     /* At least one of the two bivectors must have two distinct buffers
        (otherwise the call is utterly pointless) */
     cpl_ensure_code(cpl_bivector_get_x_data_const(self) !=
-                    cpl_bivector_get_y_data_const(self) ||
-                    cpl_bivector_get_x_data_const(other) !=
-                    cpl_bivector_get_y_data_const(other),
+                            cpl_bivector_get_y_data_const(self) ||
+                        cpl_bivector_get_x_data_const(other) !=
+                            cpl_bivector_get_y_data_const(other),
                     CPL_ERROR_UNSUPPORTED_MODE);
     cpl_ensure_code(cpl_bivector_get_size(other) == n,
                     CPL_ERROR_INCOMPATIBLE_INPUT);
 
     if (dir == CPL_SORT_ASCENDING) {
         reverse = 0;
-    } else if (dir == CPL_SORT_DESCENDING) {
+    }
+    else if (dir == CPL_SORT_DESCENDING) {
         reverse = 1;
-    } else {
+    }
+    else {
         return cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
     }
 
@@ -719,14 +732,16 @@ cpl_error_code cpl_bivector_sort(cpl_bivector * self,
        would be needed as well. This will probably not be requested */
     if (mode == CPL_SORT_BY_X) {
         data = cpl_bivector_get_x_data_const(other);
-    } else if (mode == CPL_SORT_BY_Y) {
+    }
+    else if (mode == CPL_SORT_BY_Y) {
         data = cpl_bivector_get_y_data_const(other);
-    } else {
+    }
+    else {
         return cpl_error_set_(CPL_ERROR_UNSUPPORTED_MODE);
     }
 
     cpl_ifalloc_set(&permbuf, (size_t)n * sizeof(*perm));
-    perm = (cpl_size*)cpl_ifalloc_get(&permbuf);
+    perm = (cpl_size *)cpl_ifalloc_get(&permbuf);
 
     for (i = 0; i < n; i++) {
         perm[i] = i;
@@ -734,30 +749,29 @@ cpl_error_code cpl_bivector_sort(cpl_bivector * self,
 
     if (cpl_tools_sort_stable_pattern_double(data, n, reverse, 1, perm)) {
         error = cpl_error_set_where_();
-    } else {
-        double * dselfx = cpl_bivector_get_x_data(self);
-        double * dselfy = cpl_bivector_get_y_data(self);
-        const double * dotherx = cpl_bivector_get_x_data_const(other);
-        const double * dothery = cpl_bivector_get_y_data_const(other);
-
-        if (dselfx != dotherx && dselfy != dothery &&
-            dselfx != dothery && dselfy != dotherx) {
+    }
+    else {
+        double *dselfx = cpl_bivector_get_x_data(self);
+        double *dselfy = cpl_bivector_get_y_data(self);
+        const double *dotherx = cpl_bivector_get_x_data_const(other);
+        const double *dothery = cpl_bivector_get_y_data_const(other);
 
+        if (dselfx != dotherx && dselfy != dothery && dselfx != dothery &&
+            dselfy != dotherx) {
             /* Out-of place copy of the permuted values to self */
 
             for (i = 0; i < n; i++) {
                 dselfx[i] = dotherx[perm[i]];
                 dselfy[i] = dothery[perm[i]];
             }
-
-        } else if (cpl_tools_permute_double(perm, n, dselfx, dotherx,
-                                            dselfy, dothery)) {
+        }
+        else if (cpl_tools_permute_double(perm, n, dselfx, dotherx, dselfy,
+                                          dothery)) {
             error = cpl_error_set_where_();
         }
     }
 
     cpl_ifalloc_free(&permbuf);
     return error;
-
 }
 /**@}*/
