@@ -41,7 +41,8 @@ static void ADDTYPE(cpl_column_pow)(cpl_column *, double) CPL_ATTR_NONNULL;
  * that this was done elsewhere.
  */
 
-static void ADDTYPE(cpl_column_pow)(cpl_column *column, double exponent)
+static void
+ADDTYPE(cpl_column_pow)(cpl_column *column, double exponent)
 {
     const int myerrno = errno;
     const cpl_size nullcount = cpl_column_count_invalid(column);
