@@ -137,7 +137,8 @@ typedef struct ADDTYPE(dheap)
   
   SCA is sorted in increasing order by image[SCA[i]]
  */
-static void ADDTYPE(qsort_int)(unsigned *SCA, unsigned n, const PIX_TYPE *image)
+static void
+ADDTYPE(qsort_int)(unsigned *SCA, unsigned n, const PIX_TYPE *image)
 {
     int i, ir, j, k, l;
     int i_stack[BITS];
@@ -230,7 +231,8 @@ static void ADDTYPE(qsort_int)(unsigned *SCA, unsigned n, const PIX_TYPE *image)
   @param  dh     double heap
   @param  x      current column
 */
-static void ADDTYPE(SCA_init)(ADDTYPE(dheap) * dh, unsigned x)
+static void
+ADDTYPE(SCA_init)(ADDTYPE(dheap) * dh, unsigned x)
 {
     unsigned y;
     unsigned *SCAx = dh->SCA + (dh->Ry) * x;
@@ -252,10 +254,11 @@ static void ADDTYPE(SCA_init)(ADDTYPE(dheap) * dh, unsigned x)
   @param  yold   image row of previous element
   @param  ynew   image row of new element
 */
-static void ADDTYPE(SCA_replace)(ADDTYPE(dheap) * dh,
-                                 unsigned x,
-                                 unsigned yold,
-                                 unsigned ynew)
+static void
+ADDTYPE(SCA_replace)(ADDTYPE(dheap) * dh,
+                     unsigned x,
+                     unsigned yold,
+                     unsigned ynew)
 {
     unsigned n = dh->Ry;
     unsigned *SCAx = dh->SCA + n * x;  //start of current column array
@@ -310,10 +313,8 @@ static void ADDTYPE(SCA_replace)(ADDTYPE(dheap) * dh,
   @param  B      image to heap map
   @param  heaps  heaps array
 */
-static void ADDTYPE(HEAP_SWAP)(unsigned i,
-                               unsigned j,
-                               unsigned int *B,
-                               unsigned int *heaps)
+static void
+ADDTYPE(HEAP_SWAP)(unsigned i, unsigned j, unsigned int *B, unsigned int *heaps)
 {
     unsigned ai = heaps[i];
     unsigned aj = heaps[j];
@@ -331,7 +332,8 @@ static void ADDTYPE(HEAP_SWAP)(unsigned i,
   @brief  Partion double heaps array in ADDTYPE(median) and upper/lower values
   @param  dh     double heap with elements in no particular order
 */
-static void ADDTYPE(median)(ADDTYPE(dheap) * dh)
+static void
+ADDTYPE(median)(ADDTYPE(dheap) * dh)
 {
     unsigned n = 2 * dh->m + 1;
     const unsigned k = (n - 1) / 2;
@@ -379,12 +381,13 @@ static void ADDTYPE(median)(ADDTYPE(dheap) * dh)
   @param  root    double heap position
   @return final position
  */
-static unsigned ADDTYPE(bubble_down_gt)(const PIX_TYPE *image,
-                                        unsigned *B,
-                                        unsigned *heaps,
-                                        unsigned m,
-                                        unsigned m1,
-                                        unsigned root)
+static unsigned
+ADDTYPE(bubble_down_gt)(const PIX_TYPE *image,
+                        unsigned *B,
+                        unsigned *heaps,
+                        unsigned m,
+                        unsigned m1,
+                        unsigned root)
 {
     unsigned end = m - 1;
 
@@ -416,11 +419,12 @@ static unsigned ADDTYPE(bubble_down_gt)(const PIX_TYPE *image,
   @param  child   double heap position
   @return final position
  */
-static unsigned ADDTYPE(bubble_up_gt)(const PIX_TYPE *image,
-                                      unsigned *B,
-                                      unsigned *heaps,
-                                      unsigned m1,
-                                      unsigned child)
+static unsigned
+ADDTYPE(bubble_up_gt)(const PIX_TYPE *image,
+                      unsigned *B,
+                      unsigned *heaps,
+                      unsigned m1,
+                      unsigned child)
 {
     while (child > 0) {
         const unsigned parent = (child - 1) / 2;
@@ -440,7 +444,8 @@ static unsigned ADDTYPE(bubble_up_gt)(const PIX_TYPE *image,
   @brief  establish upper heap
   @param  dh     double heap
  */
-static void ADDTYPE(heapify_gt)(ADDTYPE(dheap) * dh)
+static void
+ADDTYPE(heapify_gt)(ADDTYPE(dheap) * dh)
 {
     int start = dh->m / 2 - 1;
 
@@ -462,11 +467,12 @@ static void ADDTYPE(heapify_gt)(ADDTYPE(dheap) * dh)
   @param  root    double heap position
   @return final position
  */
-static unsigned ADDTYPE(bubble_down_lt)(const PIX_TYPE *image,
-                                        unsigned *B,
-                                        unsigned *heaps,
-                                        unsigned end,
-                                        unsigned root)
+static unsigned
+ADDTYPE(bubble_down_lt)(const PIX_TYPE *image,
+                        unsigned *B,
+                        unsigned *heaps,
+                        unsigned end,
+                        unsigned root)
 {
     while (root * 2 + 1 <= end) {
         unsigned child = root * 2 + 1;
@@ -494,10 +500,11 @@ static unsigned ADDTYPE(bubble_down_lt)(const PIX_TYPE *image,
   @param  child   double heap position
   @return final position
  */
-static unsigned ADDTYPE(bubble_up_lt)(const PIX_TYPE *image,
-                                      unsigned *B,
-                                      unsigned *heaps,
-                                      unsigned child)
+static unsigned
+ADDTYPE(bubble_up_lt)(const PIX_TYPE *image,
+                      unsigned *B,
+                      unsigned *heaps,
+                      unsigned child)
 {
     while (child > 0) {
         const unsigned parent = (child - 1) / 2;
@@ -517,7 +524,8 @@ static unsigned ADDTYPE(bubble_up_lt)(const PIX_TYPE *image,
   @brief  establish lower heap
   @param  dh     double heap
  */
-static void ADDTYPE(heapify_lt)(ADDTYPE(dheap) * dh)
+static void
+ADDTYPE(heapify_lt)(ADDTYPE(dheap) * dh)
 {
     int start = dh->m / 2 - 1;
 
@@ -533,7 +541,8 @@ static void ADDTYPE(heapify_lt)(ADDTYPE(dheap) * dh)
   @brief  Initialize double heap
   @param  dh    double heap with elements in no particular order
  */
-static void ADDTYPE(dheap_establish)(ADDTYPE(dheap) * dh)
+static void
+ADDTYPE(dheap_establish)(ADDTYPE(dheap) * dh)
 {
     ADDTYPE(median)(dh);
 
@@ -612,7 +621,8 @@ static ADDTYPE(dheap) * ADDTYPE(dheap_new)(const PIX_TYPE *image,
   @brief double heap destructor
   @param dh     double heap
  */
-static void ADDTYPE(dheap_delete)(ADDTYPE(dheap) * dh)
+static void
+ADDTYPE(dheap_delete)(ADDTYPE(dheap) * dh)
 {
     free(dh->SCA);
     free(dh->B);
@@ -628,7 +638,8 @@ static void ADDTYPE(dheap_delete)(ADDTYPE(dheap) * dh)
   @param  dh    double heap
   @return the ADDTYPE(median) element value
  */
-static PIX_TYPE ADDTYPE(dheap_median)(const ADDTYPE(dheap) * dh)
+static PIX_TYPE
+ADDTYPE(dheap_median)(const ADDTYPE(dheap) * dh)
 {
     return dh->image[dh->heaps[dh->m]];
 }
@@ -661,15 +672,16 @@ static PIX_TYPE ADDTYPE(dheap_median)(const ADDTYPE(dheap) * dh)
   the current element into place.
 
  */
-static void ADDTYPE(dheap_replace)(const PIX_TYPE *image,
-                                   unsigned *B,
-                                   unsigned *heaps,
-                                   mybool *pprev_was_larger,
-                                   mybool *pprev_was_smaller,
-                                   unsigned m,
-                                   unsigned m1,
-                                   unsigned anew,
-                                   unsigned aold)
+static void
+ADDTYPE(dheap_replace)(const PIX_TYPE *image,
+                       unsigned *B,
+                       unsigned *heaps,
+                       mybool *pprev_was_larger,
+                       mybool *pprev_was_smaller,
+                       unsigned m,
+                       unsigned m1,
+                       unsigned anew,
+                       unsigned aold)
 {
     unsigned pos;
 
@@ -803,7 +815,8 @@ static void ADDTYPE(dheap_replace)(const PIX_TYPE *image,
 
   Cost: 2 comparisons
  */
-static inline PIX_TYPE ADDTYPE(max3)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2)
+static inline PIX_TYPE
+ADDTYPE(max3)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2)
 {
     return (p0 > p1) ? ((p0 > p2) ? p0 : p2) : ((p1 > p2) ? p1 : p2);
 }
@@ -818,7 +831,8 @@ static inline PIX_TYPE ADDTYPE(max3)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2)
 
   Cost: 2 comparisons
 */
-static inline PIX_TYPE ADDTYPE(min3)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2)
+static inline PIX_TYPE
+ADDTYPE(min3)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2)
 {
     return (p0 < p1) ? ((p0 < p2) ? p0 : p2) : ((p1 < p2) ? p1 : p2);
 }
@@ -840,7 +854,8 @@ static inline PIX_TYPE ADDTYPE(min3)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2)
   2 + 2 (probability 3/7)
   = 20/7 = 2.86 comparisons
  */
-static inline PIX_TYPE ADDTYPE(
+static inline PIX_TYPE
+ADDTYPE(
     median5)(PIX_TYPE p0, PIX_TYPE p1, PIX_TYPE p2, PIX_TYPE p3, PIX_TYPE p4)
 {
     /*
@@ -879,15 +894,16 @@ static inline PIX_TYPE ADDTYPE(
   2 + 2.86 (probability 2/3) 
   = 95/21 = 4.52 comparisons
 */
-static inline PIX_TYPE ADDTYPE(median9_2)(PIX_TYPE p0,
-                                          PIX_TYPE p1,
-                                          PIX_TYPE p2,
-                                          PIX_TYPE p3,
-                                          PIX_TYPE p4,
-                                          PIX_TYPE p5,
-                                          PIX_TYPE p6,
-                                          PIX_TYPE p7,
-                                          PIX_TYPE p8)
+static inline PIX_TYPE
+ADDTYPE(median9_2)(PIX_TYPE p0,
+                   PIX_TYPE p1,
+                   PIX_TYPE p2,
+                   PIX_TYPE p3,
+                   PIX_TYPE p4,
+                   PIX_TYPE p5,
+                   PIX_TYPE p6,
+                   PIX_TYPE p7,
+                   PIX_TYPE p8)
 {
     return (p4 <= p7) ? ADDTYPE(median5)(p3, p4, p5, p2, p6)
                       : ((p1 < p7) ? ADDTYPE(median5)(p6, p7, p8, p2, p3)
@@ -914,15 +930,16 @@ static inline PIX_TYPE ADDTYPE(median9_2)(PIX_TYPE p0,
 
   Cost: 1 + 4.52 = 116/21 = 5.52 comparisons
 */
-static inline PIX_TYPE ADDTYPE(median9_1)(PIX_TYPE p0,
-                                          PIX_TYPE p1,
-                                          PIX_TYPE p2,
-                                          PIX_TYPE p3,
-                                          PIX_TYPE p4,
-                                          PIX_TYPE p5,
-                                          PIX_TYPE p6,
-                                          PIX_TYPE p7,
-                                          PIX_TYPE p8)
+static inline PIX_TYPE
+ADDTYPE(median9_1)(PIX_TYPE p0,
+                   PIX_TYPE p1,
+                   PIX_TYPE p2,
+                   PIX_TYPE p3,
+                   PIX_TYPE p4,
+                   PIX_TYPE p5,
+                   PIX_TYPE p6,
+                   PIX_TYPE p7,
+                   PIX_TYPE p8)
 {
     return (p1 < p4) ? ADDTYPE(median9_2)(p0, p1, p2, p3, p4, p5, p6, p7, p8)
                      : ADDTYPE(median9_2)(p3, p4, p5, p0, p1, p2, p6, p7, p8);
@@ -1002,11 +1019,12 @@ static inline PIX_TYPE ADDTYPE(median9_1)(PIX_TYPE p0,
   consistency. Here, an alternate lower and upper median is taken, which has
   the same effect as the +- inf chess-like pattern.
 */
-static void ADDTYPE(filter_median_1)(const PIX_TYPE *in,
-                                     PIX_TYPE *out,
-                                     unsigned Nx,
-                                     unsigned Ny,
-                                     unsigned border_mode)
+static void
+ADDTYPE(filter_median_1)(const PIX_TYPE *in,
+                         PIX_TYPE *out,
+                         unsigned Nx,
+                         unsigned Ny,
+                         unsigned border_mode)
 {
     register PIX_TYPE p0, p1, p2, p3, p4, p5;
     register PIX_TYPE p6 = (PIX_TYPE)0; /* Fix (false) uninit warning */
@@ -1225,13 +1243,14 @@ static void ADDTYPE(filter_median_1)(const PIX_TYPE *in,
   tests/cpl_filter_body.h. Do not forget to keep both in sync.
   
 */
-static void ADDTYPE(fill_row)(PIX_TYPE *in,
-                              unsigned nx,
-                              unsigned y,
-                              unsigned xmin,
-                              unsigned xmax,
-                              PIX_TYPE val1,
-                              PIX_TYPE val2)
+static void
+ADDTYPE(fill_row)(PIX_TYPE *in,
+                  unsigned nx,
+                  unsigned y,
+                  unsigned xmin,
+                  unsigned xmax,
+                  PIX_TYPE val1,
+                  PIX_TYPE val2)
 {
     unsigned x = xmin;
 
@@ -1268,14 +1287,15 @@ static void ADDTYPE(fill_row)(PIX_TYPE *in,
   filter_median_1.
   
 */
-void ADDTYPE(cpl_image_filter_fill_chess)(PIX_TYPE *in_larger,
-                                          const PIX_TYPE *in,
-                                          unsigned Nx_larger,
-                                          unsigned Ny_larger,
-                                          unsigned Nx,
-                                          unsigned Ny,
-                                          unsigned rx,
-                                          unsigned ry)
+void
+ADDTYPE(cpl_image_filter_fill_chess)(PIX_TYPE *in_larger,
+                                     const PIX_TYPE *in,
+                                     unsigned Nx_larger,
+                                     unsigned Ny_larger,
+                                     unsigned Nx,
+                                     unsigned Ny,
+                                     unsigned rx,
+                                     unsigned ry)
 {
     unsigned y;
 
@@ -1400,13 +1420,14 @@ void ADDTYPE(cpl_image_filter_fill_chess)(PIX_TYPE *in_larger,
   
   Rx = Ry = 1 is handled as a separate case.
  */
-static void ADDTYPE(filter_median)(const PIX_TYPE *in,
-                                   PIX_TYPE *out,
-                                   unsigned Nx,
-                                   unsigned Ny,
-                                   unsigned rx,
-                                   unsigned ry,
-                                   unsigned border_mode)
+static void
+ADDTYPE(filter_median)(const PIX_TYPE *in,
+                       PIX_TYPE *out,
+                       unsigned Nx,
+                       unsigned Ny,
+                       unsigned rx,
+                       unsigned ry,
+                       unsigned border_mode)
 {
     unsigned out_Nx;
     ADDTYPE(dheap) * dh;
@@ -1594,13 +1615,14 @@ static void ADDTYPE(filter_median)(const PIX_TYPE *in,
     return;
 }
 
-static void ADDTYPE(cpl_filter_median_fast)(void *out,
-                                            const void *in,
-                                            cpl_size Nx,
-                                            cpl_size Ny,
-                                            cpl_size hsizex,
-                                            cpl_size hsizey,
-                                            cpl_border_mode mode)
+static void
+ADDTYPE(cpl_filter_median_fast)(void *out,
+                                const void *in,
+                                cpl_size Nx,
+                                cpl_size Ny,
+                                cpl_size hsizex,
+                                cpl_size hsizey,
+                                cpl_border_mode mode)
 {
     const unsigned Nxu = (const unsigned)Nx;
     const unsigned Nyu = (const unsigned)Ny;
