@@ -132,6 +132,28 @@ cpl_fits_set_value(char *, int *, const cpl_property *) CPL_ATTR_NONNULL;
                             Function codes
  -----------------------------------------------------------------------------*/
 
+/**
+ * @internal
+ * @brief
+ *   Check whether the substring matches the provided names
+ *
+ * @param self      The substring (of e.g. FITS card) to compare
+ * @param nstart    Number of start keys to select against
+ * @param startkey  Keys starting with this name are matched
+ * @return TRUE iff the substring matches
+ * @see cpl_property_check_regexp, cpl_cstr_key_memcmp
+ *
+ */
+cxbool
+cpl_fits_card_check_memcmp(const cpl_cstr *self,
+                           cpl_size nstart,
+                           const cpl_cstr *startkey[])
+{
+    const cpl_memcmp filter = { nstart, startkey, 0, NULL, CPL_FALSE };
+
+    return cpl_cstr_check_memcmp(self, (cxcptr)&filter);
+}
+
 /*----------------------------------------------------------------------------*/
 /*
  * @internal
@@ -979,8 +1001,8 @@ cpl_fits_set_key(char *card,
 
             checksum = cpl_fits_check_key(key + 4, wlen - 4);
         }
-        else if (memcmp(key, "HIERARCH ", 9) != 0) {
-            /* HIERARCH but not ESO HIERARCH */
+        else if (CPL_UNLIKELY(memcmp(key, "HIERARCH ", 9) != 0)) {
+            /* Not HIERARCH */
 
             checksum = cpl_fits_check_key(key, wlen);
         }
