@@ -27,9 +27,9 @@
                         Function prototypes
  -----------------------------------------------------------------------------*/
 
-static int cpl_fits_key_is_unique(const char **[],
-                                  const cpl_cstr *,
-                                  cpl_size) CPL_ATTR_NONNULL CPL_ATTR_PURE;
+static int
+cpl_fits_key_is_unique(const char **[], const cpl_cstr *, cpl_size)
+CPL_ATTR_NONNULL CPL_ATTR_PURE;
 
 static void cpl_fits_key_free_unique(const char **[]) CPL_ATTR_NONNULL;
 static void cpl_fits_key_reset_unique(const char **[]) CPL_ATTR_NONNULL;
