@@ -165,12 +165,13 @@ static void ADDTYPE(cpl_filter_median_even)(void *,
    
 */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_filter_median_even)(void *vout,
-                                            const void *vin,
-                                            cpl_size nx,
-                                            cpl_size ny,
-                                            cpl_size rx,
-                                            cpl_size ry)
+static void
+ADDTYPE(cpl_filter_median_even)(void *vout,
+                                const void *vin,
+                                cpl_size nx,
+                                cpl_size ny,
+                                cpl_size rx,
+                                cpl_size ry)
 {
     OUT_TYPE *out = (OUT_TYPE *)vout;
     const IN_TYPE *in = (const IN_TYPE *)vin;
@@ -224,16 +225,17 @@ static void ADDTYPE(cpl_filter_median_even)(void *vout,
    
 */
 /*----------------------------------------------------------------------------*/
-static cpl_error_code ADDTYPE(cpl_filter_median_slow)(void *vout,
-                                                      cpl_binary **ppbpm,
-                                                      const void *vin,
-                                                      const cpl_binary *bpm,
-                                                      const cpl_binary *pmask,
-                                                      cpl_size nx,
-                                                      cpl_size ny,
-                                                      cpl_size rx,
-                                                      cpl_size ry,
-                                                      cpl_border_mode mode)
+static cpl_error_code
+ADDTYPE(cpl_filter_median_slow)(void *vout,
+                                cpl_binary **ppbpm,
+                                const void *vin,
+                                const cpl_binary *bpm,
+                                const cpl_binary *pmask,
+                                cpl_size nx,
+                                cpl_size ny,
+                                cpl_size rx,
+                                cpl_size ry,
+                                cpl_border_mode mode)
 {
     if (mode == CPL_BORDER_FILTER) {
         OUT_TYPE *out = (OUT_TYPE *)vout;
@@ -402,16 +404,16 @@ static cpl_error_code ADDTYPE(cpl_filter_median_slow)(void *vout,
 */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code
-    ADDTYPE_TWO(cpl_filter_average_slow)(void *vout,
-                                         cpl_binary **ppbpm,
-                                         const void *vin,
-                                         const cpl_binary *bpm,
-                                         const cpl_binary *pmask,
-                                         cpl_size nx,
-                                         cpl_size ny,
-                                         cpl_size rx,
-                                         cpl_size ry,
-                                         cpl_border_mode mode)
+ADDTYPE_TWO(cpl_filter_average_slow)(void *vout,
+                                     cpl_binary **ppbpm,
+                                     const void *vin,
+                                     const cpl_binary *bpm,
+                                     const cpl_binary *pmask,
+                                     cpl_size nx,
+                                     cpl_size ny,
+                                     cpl_size rx,
+                                     cpl_size ry,
+                                     cpl_border_mode mode)
 {
     if (mode == CPL_BORDER_FILTER) {
         OUT_TYPE *out = (OUT_TYPE *)vout;
@@ -519,16 +521,16 @@ static cpl_error_code
 */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code
-    ADDTYPE_TWO(cpl_filter_stdev_slow)(void *vout,
-                                       cpl_binary **ppbpm,
-                                       const void *vin,
-                                       const cpl_binary *bpm,
-                                       const cpl_binary *pmask,
-                                       cpl_size nx,
-                                       cpl_size ny,
-                                       cpl_size rx,
-                                       cpl_size ry,
-                                       cpl_border_mode mode)
+ADDTYPE_TWO(cpl_filter_stdev_slow)(void *vout,
+                                   cpl_binary **ppbpm,
+                                   const void *vin,
+                                   const cpl_binary *bpm,
+                                   const cpl_binary *pmask,
+                                   cpl_size nx,
+                                   cpl_size ny,
+                                   cpl_size rx,
+                                   cpl_size ry,
+                                   cpl_border_mode mode)
 {
     if (mode == CPL_BORDER_FILTER) {
         OUT_TYPE *out = (OUT_TYPE *)vout;
@@ -621,13 +623,14 @@ static cpl_error_code
    
 */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE_TWO(cpl_filter_stdev)(void *vout,
-                                          const void *vin,
-                                          cpl_size nx,
-                                          cpl_size ny,
-                                          cpl_size hsizex,
-                                          cpl_size hsizey,
-                                          cpl_border_mode border_mode)
+static void
+ADDTYPE_TWO(cpl_filter_stdev)(void *vout,
+                              const void *vin,
+                              cpl_size nx,
+                              cpl_size ny,
+                              cpl_size hsizex,
+                              cpl_size hsizey,
+                              cpl_border_mode border_mode)
 {
     OUT_TYPE *out = (OUT_TYPE *)vout;
     const IN_TYPE *in = (const IN_TYPE *)vin;
@@ -1050,13 +1053,14 @@ static void ADDTYPE_TWO(cpl_filter_stdev)(void *vout,
    
 */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE_TWO(cpl_filter_average)(void *vout,
-                                            const void *vin,
-                                            cpl_size nx,
-                                            cpl_size ny,
-                                            cpl_size hsizex,
-                                            cpl_size hsizey,
-                                            cpl_border_mode border_mode)
+static void
+ADDTYPE_TWO(cpl_filter_average)(void *vout,
+                                const void *vin,
+                                cpl_size nx,
+                                cpl_size ny,
+                                cpl_size hsizex,
+                                cpl_size hsizey,
+                                cpl_border_mode border_mode)
 {
     OUT_TYPE *out = (OUT_TYPE *)vout;
     const IN_TYPE *in = (const IN_TYPE *)vin;
@@ -1296,15 +1300,16 @@ static void ADDTYPE_TWO(cpl_filter_average)(void *vout,
    
 */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE_TWO(cpl_filter_average_bpm)(void *vout,
-                                                cpl_binary **pbpm,
-                                                const void *vin,
-                                                const cpl_binary *bpm,
-                                                cpl_size nx,
-                                                cpl_size ny,
-                                                cpl_size hsizex,
-                                                cpl_size hsizey,
-                                                cpl_border_mode border_mode)
+static void
+ADDTYPE_TWO(cpl_filter_average_bpm)(void *vout,
+                                    cpl_binary **pbpm,
+                                    const void *vin,
+                                    const cpl_binary *bpm,
+                                    cpl_size nx,
+                                    cpl_size ny,
+                                    cpl_size hsizex,
+                                    cpl_size hsizey,
+                                    cpl_border_mode border_mode)
 {
     OUT_TYPE *out = (OUT_TYPE *)vout;
     const IN_TYPE *in = (const IN_TYPE *)vin;
@@ -1720,17 +1725,18 @@ static void ADDTYPE_TWO(cpl_filter_average_bpm)(void *vout,
    
 */
 /*----------------------------------------------------------------------------*/
-static cpl_error_code ADDTYPE_TWO(cpl_filter_linear_slow)(void *vout,
-                                                          cpl_binary **ppbpm,
-                                                          const void *vin,
-                                                          const cpl_binary *bpm,
-                                                          const double *pkernel,
-                                                          cpl_size nx,
-                                                          cpl_size ny,
-                                                          cpl_boolean dodiv,
-                                                          cpl_size rx,
-                                                          cpl_size ry,
-                                                          cpl_border_mode mode)
+static cpl_error_code
+ADDTYPE_TWO(cpl_filter_linear_slow)(void *vout,
+                                    cpl_binary **ppbpm,
+                                    const void *vin,
+                                    const cpl_binary *bpm,
+                                    const double *pkernel,
+                                    cpl_size nx,
+                                    cpl_size ny,
+                                    cpl_boolean dodiv,
+                                    cpl_size rx,
+                                    cpl_size ry,
+                                    cpl_border_mode mode)
 {
     if (mode == CPL_BORDER_FILTER) {
         OUT_TYPE *out = (OUT_TYPE *)vout;
@@ -1832,17 +1838,18 @@ static cpl_error_code ADDTYPE_TWO(cpl_filter_linear_slow)(void *vout,
    
 */
 /*----------------------------------------------------------------------------*/
-static cpl_error_code ADDTYPE_TWO(cpl_filter_morpho_slow)(void *vout,
-                                                          cpl_binary **ppbpm,
-                                                          const void *vin,
-                                                          const cpl_binary *bpm,
-                                                          const double *pkernel,
-                                                          cpl_size nx,
-                                                          cpl_size ny,
-                                                          cpl_boolean dodiv,
-                                                          cpl_size rx,
-                                                          cpl_size ry,
-                                                          cpl_border_mode mode)
+static cpl_error_code
+ADDTYPE_TWO(cpl_filter_morpho_slow)(void *vout,
+                                    cpl_binary **ppbpm,
+                                    const void *vin,
+                                    const cpl_binary *bpm,
+                                    const double *pkernel,
+                                    cpl_size nx,
+                                    cpl_size ny,
+                                    cpl_boolean dodiv,
+                                    cpl_size rx,
+                                    cpl_size ry,
+                                    cpl_border_mode mode)
 {
     if (mode == CPL_BORDER_FILTER) {
         OUT_TYPE *out = (OUT_TYPE *)vout;
