@@ -619,7 +619,7 @@ cpl_image_rebin(const cpl_image *image,
 /*----------------------------------------------------------------------------*/
 /**
   @ingroup cpl_image
-  @brief    Interpolate a pixel 
+  @brief    Interpolate a pixel from its neigbors
   @param    source    Interpolation source
   @param    xpos      Pixel x floating-point position (FITS convention)
   @param    ypos      Pixel y floating-point position (FITS convention)
@@ -631,6 +631,10 @@ cpl_image_rebin(const cpl_image *image,
   @return   The interpolated pixel value, or undefined on error
   @see cpl_image_get()
 
+  This function interpolates a single pixel value as a weighted average of its
+  neigbors, specified as being inside a circle or ellipse with the distance
+  dependent weights provided by the caller.
+
   If the X- and Y-radii are identical the area of inclusion is a circle,
   otherwise it is an ellipse, with the larger of the two radii as the
   semimajor axis and the other as the semiminor axis.
@@ -658,6 +662,7 @@ cpl_image_rebin(const cpl_image *image,
   
   Here is an example of a simple image unwarping (with error-checking omitted
   for brevity):
+    @code
 
     const double xyradius = CPL_KERNEL_DEF_WIDTH;
   
@@ -686,6 +691,7 @@ cpl_image_rebin(const cpl_image *image,
 
     cpl_vector_delete(xyprofile);
 
+    @endcode
 
   Possible #_cpl_error_code_ set in this function:
   - CPL_ERROR_NULL_INPUT if (one of) the input pointer(s) is NULL
