@@ -97,7 +97,8 @@ cpl_imagelist_new(void)
   This function loads all the images of a specified extension (NAXIS=2
   or 3) into an image list.
 
-  Type can be CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT or CPL_TYPE_INT.
+  Type can be CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT, CPL_TYPE_INT or
+  CPL_TYPE_UNSPECIFIED.
   The loaded images have an empty bad pixel map.
 
   The returned cpl_imagelist must be deallocated using cpl_imagelist_delete()
@@ -105,11 +106,11 @@ cpl_imagelist_new(void)
   Possible #_cpl_error_code_ set in this function:
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
   - CPL_ERROR_ILLEGAL_INPUT if xtnum is negative
-  - CPL_ERROR_INVALID_TYPE if the passed type is not supported
-  - CPL_ERROR_FILE_IO If the file cannot be opened or read, or if xtnum is
-                      bigger than the number of extensions in the FITS file
-  - CPL_ERROR_BAD_FILE_FORMAT if the file cannot be parsed
-  - CPL_ERROR_DATA_NOT_FOUND if the data cannot be read from the file
+  - CPL_ERROR_FILE_IO if the file cannot be opened or does not exist
+  - CPL_ERROR_DATA_NOT_FOUND if the specified extension has no image data
+  - CPL_ERROR_BAD_FILE_FORMAT if the data cannot be loaded from the file
+    including attempting to read beyond EOF
+  - CPL_ERROR_INVALID_TYPE if the requested type is not supported
  */
 /*----------------------------------------------------------------------------*/
 cpl_imagelist *
@@ -147,12 +148,13 @@ cpl_imagelist_load(const char *filename, cpl_type im_type, cpl_size xtnum)
 
   Possible #_cpl_error_code_ set in this function:
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
-  - CPL_ERROR_ILLEGAL_INPUT if xtnum is negative
-  - CPL_ERROR_INVALID_TYPE if the passed type is not supported
-  - CPL_ERROR_ACCESS_OUT_OF_RANGE if xtnum is bigger than the number of
-    extensions in the FITS file
-  - CPL_ERROR_BAD_FILE_FORMAT if the file cannot be parsed
-  - CPL_ERROR_DATA_NOT_FOUND if the data cannot be read from the file
+  - CPL_ERROR_ILLEGAL_INPUT if the passed extension number is negative or
+    the window position is invalid
+  - CPL_ERROR_FILE_IO if the file cannot be opened or does not exist
+  - CPL_ERROR_DATA_NOT_FOUND if the specified extension has no image data
+  - CPL_ERROR_BAD_FILE_FORMAT if the data cannot be loaded from the file
+    including attempting to read beyond EOF
+  - CPL_ERROR_INVALID_TYPE if the requested pixel type is not supported
  */
 /*----------------------------------------------------------------------------*/
 cpl_imagelist *
@@ -412,8 +414,6 @@ cpl_imagelist_empty(cpl_imagelist *self)
             cpl_image *del = cpl_imagelist_unset(self, i);
             const cpl_mask *bpm = cpl_image_get_bpm_const(del);
 
-            cpl_image_delete(del);
-
             /* If this image was inserted more than once into the list,
                the other insertions must be unset without a delete. */
             while (--i >= 0) {
@@ -430,6 +430,8 @@ cpl_imagelist_empty(cpl_imagelist *self)
                     assert(sameimg == del);
                 }
             }
+
+            cpl_image_delete(del);
         }
     }
 
