@@ -30,10 +30,11 @@
 
  */
 /*----------------------------------------------------------------------------*/
-void APPENDOPER(CPL_MASK_BINARY_WOPER)(cpl_binary *self,
-                                       const cpl_binary *first,
-                                       const cpl_binary *second,
-                                       size_t nxy)
+void
+APPENDOPER(CPL_MASK_BINARY_WOPER)(cpl_binary *self,
+                                  const cpl_binary *first,
+                                  const cpl_binary *second,
+                                  size_t nxy)
 
 {
     CPL_MASK_REGISTER_TYPE *word0 = (CPL_MASK_REGISTER_TYPE *)self;
@@ -89,10 +90,11 @@ void APPENDOPER(CPL_MASK_BINARY_WOPER)(cpl_binary *self,
 
  */
 /*----------------------------------------------------------------------------*/
-void APPENDOPERS(CPL_MASK_BINARY_WOPER)(cpl_binary *self,
-                                        const cpl_binary *first,
-                                        cpl_bitmask second,
-                                        size_t nxy)
+void
+APPENDOPERS(CPL_MASK_BINARY_WOPER)(cpl_binary *self,
+                                   const cpl_binary *first,
+                                   cpl_bitmask second,
+                                   size_t nxy)
 
 {
     CPL_MASK_REGISTER_TYPE *word0 = (CPL_MASK_REGISTER_TYPE *)self;
