@@ -80,11 +80,6 @@ CPL_BEGIN_DECLS
 
 #define CPL_FITS_EXACT_PRIM CXSTR("BLOCKED", 7), CPL_FITS_EXACT_EXT
 
-#define CPL_FITS_START                                           \
-    CXSTR("NAXIS", 5), CXSTR("TFORM", 5), CXSTR("TTYPE", 5),     \
-        CXSTR("TUNIT", 5), CXSTR("TZERO", 5), CXSTR("TSCAL", 5), \
-        CXSTR("TDIM", 4), CXSTR("TNULL", 5)
-
 #define CPL_FITS_START                                           \
     CXSTR("NAXIS", 5), CXSTR("TFORM", 5), CXSTR("TTYPE", 5),     \
         CXSTR("TUNIT", 5), CXSTR("TZERO", 5), CXSTR("TSCAL", 5), \
@@ -97,27 +92,6 @@ CPL_BEGIN_DECLS
 
 #define CPL_FITS_START_EXT CXSTR("ORIGIN", 6), CPL_FITS_START_PRIM
 
-#define CPL_FITS_BADKEYS                                       \
-    "SIMPLE|BSCALE|BZERO|EXTEND"                               \
-    "|XTENSION|BITPIX|NAXIS[0-9]*|PCOUNT|GCOUNT|DATE"          \
-    ""                                                         \
-    "|TFIELDS|TFORM[0-9]*|TTYPE[0-9]*|TUNIT[0-9]*|TZERO[0-9]*" \
-    "|TSCAL[0-9]*|TDIM[0-9]*|TNULL[0-9]*"
-
-#define CPL_FITS_BADKEYS_PRIM        \
-    "^(" CPL_FITS_BADKEYS "|BLOCKED" \
-    ")$"
-
-#define CPL_FITS_BADKEYS_EXT "^(" CPL_FITS_BADKEYS "|ORIGIN[0-9]*)$"
-
-#define CPL_FITS_COMPRKEYS                           \
-    "^("                                             \
-    "ZIMAGE|ZCMPTYPE|ZNAXIS"                         \
-    "|ZTENSION|ZPCOUNT|ZGCOUNT|ZNAME[0-9]|ZVAL[0-9]" \
-    "|ZTILE[0-9]|ZBITPIX|ZNAXIS[0-9]|ZSCALE|ZZERO"   \
-    "|ZBLANK|ZHECKSUM|ZDATASUM"                      \
-    ")$"
-
 /**
    @internal
    @brief CFITSIO wrapper without warning for const violation
