@@ -72,7 +72,8 @@ static void ADDTYPE(cpl_tools_get_0th)(CPL_TYPE *, size_t) CPL_ATTR_NONNULL;
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_0th)(CPL_TYPE *self, size_t n)
+static void
+ADDTYPE(cpl_tools_get_0th)(CPL_TYPE *self, size_t n)
 {
     CPL_TYPE min = self[0];
     size_t amin = 0;
@@ -101,7 +102,8 @@ static void ADDTYPE(cpl_tools_get_0th)(CPL_TYPE *self, size_t n)
 
  */
 /*----------------------------------------------------------------------------*/
-void ADDTYPE(cpl_tools_flip)(CPL_TYPE *self, size_t n)
+void
+ADDTYPE(cpl_tools_flip)(CPL_TYPE *self, size_t n)
 {
     for (size_t i = 0; i < n / 2; i++) {
         CPL_TYPE_SWAP(self[i], self[n - 1 - i]);
@@ -137,7 +139,8 @@ void ADDTYPE(cpl_tools_flip)(CPL_TYPE *self, size_t n)
   The median of the integers (1 2 3 4) is 2 (due to the integer arithmetic).
  */
 /*----------------------------------------------------------------------------*/
-CPL_TYPE ADDTYPE(cpl_tools_get_median)(CPL_TYPE *self, cpl_size n)
+CPL_TYPE
+ADDTYPE(cpl_tools_get_median)(CPL_TYPE *self, cpl_size n)
 {
     switch (n) {
         case 3:
@@ -196,7 +199,8 @@ CPL_TYPE ADDTYPE(cpl_tools_get_median)(CPL_TYPE *self, cpl_size n)
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_median_3)(CPL_TYPE *self)
+static void
+ADDTYPE(cpl_tools_get_median_3)(CPL_TYPE *self)
 {
 #ifdef CPL_TOOLS_STRICT_ERROR_CHECKING
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, (CPL_TYPE)0);
@@ -224,7 +228,8 @@ static void ADDTYPE(cpl_tools_get_median_3)(CPL_TYPE *self)
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_median_5)(CPL_TYPE *self)
+static void
+ADDTYPE(cpl_tools_get_median_5)(CPL_TYPE *self)
 {
 #ifdef CPL_TOOLS_STRICT_ERROR_CHECKING
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, (CPL_TYPE)0);
@@ -260,7 +265,8 @@ static void ADDTYPE(cpl_tools_get_median_5)(CPL_TYPE *self)
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_median_6)(CPL_TYPE *self)
+static void
+ADDTYPE(cpl_tools_get_median_6)(CPL_TYPE *self)
 {
 #ifdef CPL_TOOLS_STRICT_ERROR_CHECKING
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, (CPL_TYPE)0);
@@ -299,7 +305,8 @@ static void ADDTYPE(cpl_tools_get_median_6)(CPL_TYPE *self)
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_median_7)(CPL_TYPE *self)
+static void
+ADDTYPE(cpl_tools_get_median_7)(CPL_TYPE *self)
 {
 #ifdef CPL_TOOLS_STRICT_ERROR_CHECKING
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, (CPL_TYPE)0);
@@ -335,7 +342,8 @@ static void ADDTYPE(cpl_tools_get_median_7)(CPL_TYPE *self)
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_median_9)(CPL_TYPE *self)
+static void
+ADDTYPE(cpl_tools_get_median_9)(CPL_TYPE *self)
 {
 #ifdef CPL_TOOLS_STRICT_ERROR_CHECKING
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, (CPL_TYPE)0);
@@ -380,7 +388,8 @@ static void ADDTYPE(cpl_tools_get_median_9)(CPL_TYPE *self)
 
  */
 /*----------------------------------------------------------------------------*/
-static void ADDTYPE(cpl_tools_get_median_25)(CPL_TYPE *self)
+static void
+ADDTYPE(cpl_tools_get_median_25)(CPL_TYPE *self)
 {
 #ifdef CPL_TOOLS_STRICT_ERROR_CHECKING
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, (CPL_TYPE)0);
@@ -503,7 +512,8 @@ static void ADDTYPE(cpl_tools_get_median_25)(CPL_TYPE *self)
 
  */
 /*----------------------------------------------------------------------------*/
-double ADDTYPE(cpl_tools_get_mean)(const CPL_TYPE *a, cpl_size nn)
+double
+ADDTYPE(cpl_tools_get_mean)(const CPL_TYPE *a, cpl_size nn)
 {
     double mean = 0.0;
     const size_t n = (size_t)nn;
@@ -609,9 +619,10 @@ $$\sum_{i=1}^{N+1} (x_i - \overline{x}_{n+1})2 = \sum_{i=1}^N (x_i - \overline{x
 
  */
 /*----------------------------------------------------------------------------*/
-double ADDTYPE(cpl_tools_get_variancesum)(const CPL_TYPE *a,
-                                          cpl_size nn,
-                                          double *pmean)
+double
+ADDTYPE(cpl_tools_get_variancesum)(const CPL_TYPE *a,
+                                   cpl_size nn,
+                                   double *pmean)
 {
     double varsum = 0.0;
     double mean = 0.0;
@@ -649,9 +660,8 @@ double ADDTYPE(cpl_tools_get_variancesum)(const CPL_TYPE *a,
   @see cpl_tools_get_variancesum_double()
  */
 /*----------------------------------------------------------------------------*/
-double ADDTYPE(cpl_tools_get_variance)(const CPL_TYPE *a,
-                                       cpl_size n,
-                                       double *pmean)
+double
+ADDTYPE(cpl_tools_get_variance)(const CPL_TYPE *a, cpl_size n, double *pmean)
 {
     const double varsum = ADDTYPE(cpl_tools_get_variancesum)(a, n, pmean);
 
@@ -674,7 +684,8 @@ double ADDTYPE(cpl_tools_get_variance)(const CPL_TYPE *a,
 
  */
 /*----------------------------------------------------------------------------*/
-static int ADDTYPE(compar_ascn)(const void *p1, const void *p2)
+static int
+ADDTYPE(compar_ascn)(const void *p1, const void *p2)
 {
     const CPL_TYPE a1 = *(const CPL_TYPE *)p1;
     const CPL_TYPE a2 = *(const CPL_TYPE *)p2;
@@ -695,7 +706,8 @@ static int ADDTYPE(compar_ascn)(const void *p1, const void *p2)
 
  */
 /*----------------------------------------------------------------------------*/
-static int ADDTYPE(compar_desc)(const void *p1, const void *p2)
+static int
+ADDTYPE(compar_desc)(const void *p1, const void *p2)
 {
     const CPL_TYPE a1 = *(const CPL_TYPE *)p1;
     const CPL_TYPE a2 = *(const CPL_TYPE *)p2;
@@ -728,7 +740,7 @@ static int ADDTYPE(compar_desc)(const void *p1, const void *p2)
  */
 /*----------------------------------------------------------------------------*/
 CPL_TYPE
-    ADDTYPE(cpl_tools_quickselection)(CPL_TYPE *self, cpl_size nn, cpl_size kk)
+ADDTYPE(cpl_tools_quickselection)(CPL_TYPE *self, cpl_size nn, cpl_size kk)
 {
     const size_t n = (size_t)nn;
     const size_t k = (size_t)kk;
@@ -817,7 +829,8 @@ CPL_TYPE
 
  */
 /*----------------------------------------------------------------------------*/
-CPL_TYPE ADDTYPE(cpl_tools_get_kth)(CPL_TYPE *self, cpl_size n, cpl_size k)
+CPL_TYPE
+ADDTYPE(cpl_tools_get_kth)(CPL_TYPE *self, cpl_size n, cpl_size k)
 {
     register cpl_size l = 0;
     register cpl_size m = n - 1;
@@ -883,7 +896,8 @@ CPL_TYPE ADDTYPE(cpl_tools_get_kth)(CPL_TYPE *self, cpl_size n, cpl_size k)
   - CPL_ERROR_ILLEGAL_INPUT
  */
 /*----------------------------------------------------------------------------*/
-void ADDTYPE(cpl_tools_sort_ascn)(CPL_TYPE *self, int n)
+void
+ADDTYPE(cpl_tools_sort_ascn)(CPL_TYPE *self, int n)
 {
     qsort(self, n, sizeof(*self), ADDTYPE(compar_ascn));
 }
@@ -901,7 +915,8 @@ void ADDTYPE(cpl_tools_sort_ascn)(CPL_TYPE *self, int n)
   - CPL_ERROR_ILLEGAL_INPUT
  */
 /*----------------------------------------------------------------------------*/
-void ADDTYPE(cpl_tools_sort_desc)(CPL_TYPE *self, int n)
+void
+ADDTYPE(cpl_tools_sort_desc)(CPL_TYPE *self, int n)
 {
     qsort(self, (size_t)n, sizeof(*self), ADDTYPE(compar_desc));
 }
@@ -922,7 +937,8 @@ void ADDTYPE(cpl_tools_sort_desc)(CPL_TYPE *self, int n)
   - CPL_ERROR_ILLEGAL_INPUT
  */
 /*----------------------------------------------------------------------------*/
-cpl_error_code ADDTYPE(cpl_tools_sort)(CPL_TYPE *self, cpl_size nn)
+cpl_error_code
+ADDTYPE(cpl_tools_sort)(CPL_TYPE *self, cpl_size nn)
 {
     const size_t n = (size_t)nn;
     size_t i, ir, j, k, l;
@@ -1027,11 +1043,12 @@ cpl_error_code ADDTYPE(cpl_tools_sort)(CPL_TYPE *self, cpl_size nn)
   - CPL_ERROR_ILLEGAL_INPUT
  */
 /*----------------------------------------------------------------------------*/
-cpl_error_code ADDTYPE(cpl_tools_sort_stable_pattern)(CPL_TYPE const *self,
-                                                      cpl_size n,
-                                                      int reverse,
-                                                      int stable,
-                                                      cpl_size *sort_pattern)
+cpl_error_code
+ADDTYPE(cpl_tools_sort_stable_pattern)(CPL_TYPE const *self,
+                                       cpl_size n,
+                                       int reverse,
+                                       int stable,
+                                       cpl_size *sort_pattern)
 {
     cpl_size i;
 
@@ -1165,12 +1182,13 @@ cpl_error_code ADDTYPE(cpl_tools_sort_stable_pattern)(CPL_TYPE const *self,
   - CPL_ERROR_INCOMPATIBLE_INPUT only one of bread/bwrite is NULL
  */
 /*----------------------------------------------------------------------------*/
-cpl_error_code ADDTYPE(cpl_tools_permute)(cpl_size *self,
-                                          cpl_size n,
-                                          CPL_TYPE *awrite,
-                                          CPL_TYPE const *aread,
-                                          CPL_TYPE *bwrite,
-                                          CPL_TYPE const *bread)
+cpl_error_code
+ADDTYPE(cpl_tools_permute)(cpl_size *self,
+                           cpl_size n,
+                           CPL_TYPE *awrite,
+                           CPL_TYPE const *aread,
+                           CPL_TYPE *bwrite,
+                           CPL_TYPE const *bread)
 {
     cpl_size ido = 0; /* First element in cycle to process */
     const cpl_boolean dob = bwrite != NULL;
