@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@
 #endif
 
 #define CPL_XSTRINGIFY(TOSTRING) #TOSTRING
-#define CPL_STRINGIFY(TOSTRING) CPL_XSTRINGIFY(TOSTRING)
+#define CPL_STRINGIFY(TOSTRING)  CPL_XSTRINGIFY(TOSTRING)
 
 /*
   This symbol defines the level of usage of the memory module.
@@ -109,42 +109,42 @@
                         Private variables
  -----------------------------------------------------------------------------*/
 
-static const char * cpl_xmemory_type[]
-    = {"free", "malloc", "calloc", "realloc"};
+static const char *cpl_xmemory_type[] = { "free", "malloc", "calloc",
+                                          "realloc" };
 
 /* Number of active cells */
-static size_t       cpl_xmemory_ncells = 0;
+static size_t cpl_xmemory_ncells = 0;
 
 /* Peak number of pointers ever seen for diagnostics */
-static size_t       cpl_xmemory_max_cells = 0;
+static size_t cpl_xmemory_max_cells = 0;
 
 /* Total number of allocations for diagnostics - via free()/realloc()*/
-static size_t       cpl_xmemory_sum_cells = 0;
+static size_t cpl_xmemory_sum_cells = 0;
 
 /* Total allocated RAM in bytes */
-static size_t       cpl_xmemory_alloc_ram = 0;
+static size_t cpl_xmemory_alloc_ram = 0;
 
 /* Peak allocation ever seen for diagnostics */
-static size_t       cpl_xmemory_alloc_max = 0;
+static size_t cpl_xmemory_alloc_max = 0;
 
 /* The current size of the xmemory table */
-static size_t       cpl_xmemory_table_size = 0;
+static size_t cpl_xmemory_table_size = 0;
 
 /* The default size of the xmemory table, when it is non-empty */
-static size_t       cpl_xmemory_table_size_max = 0;
+static size_t cpl_xmemory_table_size_max = 0;
 
 static int cpl_xmemory_fatal = 0;
 
 /* Various infos about the pointers */
 /* List of pointers */
-static const void   ** cpl_xmemory_p_val;
+static const void **cpl_xmemory_p_val;
 
 /* Type of allocation */
 /* - CPL_XMEMORY_TYPE_FREE means no allocation */
-static unsigned char * cpl_xmemory_p_type;
+static unsigned char *cpl_xmemory_p_type;
 
 /* Size of allocated memory [bytes] */
-static size_t        * cpl_xmemory_p_size;
+static size_t *cpl_xmemory_p_size;
 
 /*-----------------------------------------------------------------------------
                     Private function prototypes
@@ -173,27 +173,24 @@ static size_t cpl_xmemory_findfree(const void *);
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-void * cpl_xmemory_malloc_count(size_t size)
+inline void *
+cpl_xmemory_malloc_count(size_t size)
 {
-
-    void * ptr = malloc(size);
+    void *ptr = malloc(size);
 
 
     if (ptr != NULL) {
-
-#       ifdef _OPENMP
-#       pragma omp atomic
-#       endif
+#ifdef _OPENMP
+#pragma omp atomic
+#endif
         cpl_xmemory_ncells++;
         /* Remember peak allocation */
         /* FIXME: This non-thread-safe check is incorrect, but might still
            produce a useful estimate */
         if (cpl_xmemory_ncells > cpl_xmemory_max_cells)
             cpl_xmemory_max_cells = cpl_xmemory_ncells;
-
-    } else if (size != 0) {
-
+    }
+    else if (size != 0) {
         fprintf(stderr, "cpl_xmemory fatal error: malloc(%zu) returned NULL:\n",
                 size);
         perror(NULL);
@@ -201,11 +198,9 @@ void * cpl_xmemory_malloc_count(size_t size)
         cpl_xmemory_status(cpl_xmemory_table_size ? 2 : 1);
         assert(ptr != NULL); /* More informative, if enabled */
         abort();
-
     }
 
     return ptr;
-
 }
 
 /*----------------------------------------------------------------------------*/
@@ -219,39 +214,36 @@ void * cpl_xmemory_malloc_count(size_t size)
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-void * cpl_xmemory_calloc_count(size_t nmemb, size_t size)
+inline void *
+cpl_xmemory_calloc_count(size_t nmemb, size_t size)
 {
-
-    void * ptr = calloc(nmemb, size);
+    void *ptr = calloc(nmemb, size);
 
 
     if (ptr != NULL) {
-
-#       ifdef _OPENMP
-#       pragma omp atomic
-#       endif
+#ifdef _OPENMP
+#pragma omp atomic
+#endif
         cpl_xmemory_ncells++;
         /* Remember peak allocation */
         /* FIXME: This non-thread-safe check is incorrect, but might still
            produce a useful estimate */
         if (cpl_xmemory_ncells > cpl_xmemory_max_cells)
             cpl_xmemory_max_cells = cpl_xmemory_ncells;
-
-    } else if (size != 0 && nmemb != 0) {
-
-        fprintf(stderr, "cpl_xmemory fatal error: calloc(%zu, %zu) returned "
-                "NULL:\n", nmemb, size);
+    }
+    else if (size != 0 && nmemb != 0) {
+        fprintf(stderr,
+                "cpl_xmemory fatal error: calloc(%zu, %zu) returned "
+                "NULL:\n",
+                nmemb, size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
         cpl_xmemory_status(cpl_xmemory_table_size ? 2 : 1);
         assert(ptr != NULL); /* More informative, if enabled */
         abort();
-
     }
 
     return ptr;
-
 }
 
 
@@ -266,11 +258,10 @@ void * cpl_xmemory_calloc_count(size_t nmemb, size_t size)
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
+inline void *
+cpl_xmemory_realloc_count(void *oldptr, size_t size)
 {
-
-    void * ptr;
+    void *ptr;
 
     if (oldptr == NULL) {
         /* This is just another way to do a malloc() */
@@ -279,13 +270,16 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
 
 #ifndef _OPENMP
         /* Need to disable this non-threadsafe check with thread-support */
-    } else if (cpl_xmemory_ncells == 0) {
-        fprintf(stderr, "cpl_xmemory error: Ignoring realloc() to %zu bytes on "
-                "unallocated pointer (%p)\n", size, oldptr);
+    }
+    else if (cpl_xmemory_ncells == 0) {
+        fprintf(stderr,
+                "cpl_xmemory error: Ignoring realloc() to %zu bytes on "
+                "unallocated pointer (%p)\n",
+                size, oldptr);
         ptr = NULL;
 #endif
-    } else {
-
+    }
+    else {
         /* assert( oldptr != NULL ); */
 
         ptr = realloc(oldptr, size);
@@ -293,10 +287,11 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
         cpl_xmemory_sum_cells++; /* Approximate during multi-threading */
 
         if (ptr == NULL) {
-
             if (size != 0) {
-                fprintf(stderr, "cpl_xmemory fatal error: realloc(%p, %zu) "
-                        "returned NULL:\n", oldptr, size);
+                fprintf(stderr,
+                        "cpl_xmemory fatal error: realloc(%p, %zu) "
+                        "returned NULL:\n",
+                        oldptr, size);
                 perror(NULL);
                 cpl_xmemory_fatal = 1;
                 cpl_xmemory_status(cpl_xmemory_table_size ? 2 : 1);
@@ -305,9 +300,9 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
             }
 
             /* This is just another way to do a free() */
-#           ifdef _OPENMP
-#           pragma omp atomic
-#           endif
+#ifdef _OPENMP
+#pragma omp atomic
+#endif
             cpl_xmemory_ncells--;
         }
     }
@@ -325,23 +320,25 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
 
  */
 /*----------------------------------------------------------------------------*/
-void cpl_xmemory_free_count(void * ptr)
+void
+cpl_xmemory_free_count(void *ptr)
 {
-
     if (ptr != NULL) {
 #ifndef _OPENMP
         /* Need to disable this non-threadsafe check with thread-support */
         if (cpl_xmemory_ncells == 0) {
-            fprintf(stderr, "cpl_xmemory error: Ignoring free() on "
-                    "unallocated pointer (%p)\n", ptr);
+            fprintf(stderr,
+                    "cpl_xmemory error: Ignoring free() on "
+                    "unallocated pointer (%p)\n",
+                    ptr);
             return;
         }
 #endif
         free(ptr);
 
-#       ifdef _OPENMP
-#       pragma omp atomic
-#       endif
+#ifdef _OPENMP
+#pragma omp atomic
+#endif
         cpl_xmemory_ncells--;
 
         cpl_xmemory_sum_cells++; /* Approximate during multi-threading */
@@ -359,9 +356,10 @@ void cpl_xmemory_free_count(void * ptr)
 
  */
 /*----------------------------------------------------------------------------*/
-void * cpl_xmemory_malloc(size_t size)
+void *
+cpl_xmemory_malloc(size_t size)
 {
-    void * ptr;
+    void *ptr;
     size_t pos;
 
     if (size == 0) {
@@ -372,9 +370,8 @@ void * cpl_xmemory_malloc(size_t size)
 
     ptr = cpl_xmemory_malloc_count(size);
 
-    if (cpl_xmemory_ncells
-        >= cpl_xmemory_table_size * CPL_XMEMORY_RESIZE_THRESHOLD) {
-
+    if (cpl_xmemory_ncells >=
+        cpl_xmemory_table_size * CPL_XMEMORY_RESIZE_THRESHOLD) {
         /* Initialize table if needed */
         if (cpl_xmemory_table_size == 0) {
             cpl_xmemory_init();
@@ -401,9 +398,10 @@ void * cpl_xmemory_malloc(size_t size)
 
  */
 /*----------------------------------------------------------------------------*/
-void * cpl_xmemory_calloc(size_t nmemb, size_t size)
+void *
+cpl_xmemory_calloc(size_t nmemb, size_t size)
 {
-    void * ptr;
+    void *ptr;
     size_t pos;
 
 
@@ -415,9 +413,8 @@ void * cpl_xmemory_calloc(size_t nmemb, size_t size)
 
     ptr = cpl_xmemory_calloc_count(nmemb, size);
 
-    if (cpl_xmemory_ncells
-        >= cpl_xmemory_table_size * CPL_XMEMORY_RESIZE_THRESHOLD) {
-
+    if (cpl_xmemory_ncells >=
+        cpl_xmemory_table_size * CPL_XMEMORY_RESIZE_THRESHOLD) {
         /* Initialize table if needed */
         if (cpl_xmemory_table_size == 0) {
             cpl_xmemory_init();
@@ -443,9 +440,10 @@ void * cpl_xmemory_calloc(size_t nmemb, size_t size)
   @return   1 newly allocated pointer.
  */
 /*----------------------------------------------------------------------------*/
-void * cpl_xmemory_realloc(void * oldptr, size_t size)
+void *
+cpl_xmemory_realloc(void *oldptr, size_t size)
 {
-    void * ptr;
+    void *ptr;
     size_t pos = cpl_xmemory_table_size; /* Avoid (false) uninit warning */
 
     if (size == 0) {
@@ -456,18 +454,21 @@ void * cpl_xmemory_realloc(void * oldptr, size_t size)
     }
 
     if (oldptr != NULL) {
-
         if (cpl_xmemory_table_size == 0) {
-            fprintf(stderr, "cpl_xmemory error: Ignoring realloc() of %zu bytes"
-                    " requested on unallocated pointer (%p)\n", size, oldptr);
+            fprintf(stderr,
+                    "cpl_xmemory error: Ignoring realloc() of %zu bytes"
+                    " requested on unallocated pointer (%p)\n",
+                    size, oldptr);
             return NULL;
         }
 
         pos = cpl_xmemory_findcell(oldptr);
 
         if (pos == cpl_xmemory_table_size) {
-            fprintf(stderr, "cpl_xmemory error: Ignoring realloc() of %zu bytes"
-                    " requested on unallocated pointer (%p)\n", size, oldptr);
+            fprintf(stderr,
+                    "cpl_xmemory error: Ignoring realloc() of %zu bytes"
+                    " requested on unallocated pointer (%p)\n",
+                    size, oldptr);
             return NULL;
         }
 
@@ -481,7 +482,6 @@ void * cpl_xmemory_realloc(void * oldptr, size_t size)
 
         /* Remove cell from main table */
         cpl_xmemory_remcell(pos);
-
     }
 
     ptr = cpl_xmemory_realloc_count(oldptr, size);
@@ -489,10 +489,8 @@ void * cpl_xmemory_realloc(void * oldptr, size_t size)
     /* assert( ptr != NULL ); */
 
     if (ptr != oldptr) {
-
-        if (cpl_xmemory_ncells >= cpl_xmemory_table_size
-            * CPL_XMEMORY_RESIZE_THRESHOLD) {
-
+        if (cpl_xmemory_ncells >=
+            cpl_xmemory_table_size * CPL_XMEMORY_RESIZE_THRESHOLD) {
             /* Initialize table if needed */
             if (cpl_xmemory_table_size == 0) {
                 cpl_xmemory_init();
@@ -503,7 +501,6 @@ void * cpl_xmemory_realloc(void * oldptr, size_t size)
         }
 
         pos = cpl_xmemory_findfree(ptr);
-
     }
 
     /* Add cell into general table */
@@ -527,17 +524,20 @@ void * cpl_xmemory_realloc(void * oldptr, size_t size)
 
  */
 /*----------------------------------------------------------------------------*/
-void cpl_xmemory_free(void * ptr)
+void
+cpl_xmemory_free(void *ptr)
 {
-
     size_t pos;
 
     /* Do nothing for a NULL pointer */
-    if (ptr == NULL) return;
+    if (ptr == NULL)
+        return;
 
     if (cpl_xmemory_ncells == 0) {
-        fprintf(stderr, "cpl_xmemory error: Ignoring free() on unallocated "
-                "pointer (%p)\n", ptr);
+        fprintf(stderr,
+                "cpl_xmemory error: Ignoring free() on unallocated "
+                "pointer (%p)\n",
+                ptr);
         return;
     }
 
@@ -546,25 +546,27 @@ void cpl_xmemory_free(void * ptr)
     pos = cpl_xmemory_findcell(ptr);
 
     if (pos == cpl_xmemory_table_size) {
-        fprintf(stderr, "cpl_xmemory error: Ignoring free() on unallocated "
-                "pointer (%p)\n", ptr);
+        fprintf(stderr,
+                "cpl_xmemory error: Ignoring free() on unallocated "
+                "pointer (%p)\n",
+                ptr);
         return;
-
     }
 
     /* free + below decrement copied from cpl_xmemory_free_count() */
     free(ptr);
 
     /* Decrement number of allocated pointers */
-#   ifdef _OPENMP
-#   pragma omp atomic
-#   endif
+#ifdef _OPENMP
+#pragma omp atomic
+#endif
     cpl_xmemory_ncells--;
 
     if (cpl_xmemory_ncells > 0) {
         /* Remove cell from main table */
         cpl_xmemory_remcell(pos);
-    } else {
+    }
+    else {
         /* There are no more active pointers, deallocate internal memory */
         cpl_xmemory_end();
     }
@@ -584,85 +586,85 @@ void cpl_xmemory_free(void * ptr)
   features.
  */
 /*----------------------------------------------------------------------------*/
-void cpl_xmemory_status(int mode)
+void
+cpl_xmemory_status(int mode)
 {
+    if (mode > 0) {
+        const size_t rowsize =
+            sizeof(void *) + sizeof(size_t) + sizeof(unsigned char);
 
-    if (mode > 0)
-        {
-            const size_t rowsize =
-                sizeof(void*) +
-                sizeof(size_t)+
-                sizeof(unsigned char);
+        fprintf(stderr, "#----- Memory Diagnostics -----\n");
 
-            fprintf(stderr, "#----- Memory Diagnostics -----\n");
-
-            if (mode == 2) {
-                fprintf(stderr,
-                        "Total allocations [pointer]:  %zu\n"
-                        "Peak pointer usage [pointer]: %zu\n"
-                        "Peak memory allocation [B]:   %zu\n"
-                        "Peak table size [pointer]:    %zu\n"
-                        "Peak table size [B]:          %zu\n",
-                        cpl_xmemory_sum_cells,
-                        cpl_xmemory_max_cells,
-                        cpl_xmemory_alloc_max,
-                        cpl_xmemory_table_size_max,
-                        cpl_xmemory_table_size_max * rowsize);
-            } else {
-                fprintf(stderr, "Total number of allocations"
-#               ifdef _OPENMP
-                        /* cpl_xmemory_sum_cells is not updated thread-safely */
-                        " (approximate)"
-#               endif
-                        ": %zu\n", cpl_xmemory_sum_cells);
-                fprintf(stderr, "Maximum number of pointers"
-#               ifdef _OPENMP
-                        /* cpl_xmemory_max_cells is not updated thread-safely */
-                        " (approximate)"
-#               endif
-                        ": %zu\n", cpl_xmemory_max_cells);
-            }
-
-            fprintf(stderr, "#----- Memory Currently Allocated -----\n");
-
-            fprintf(stderr, "Number of active pointers:    %zu\n",
-                    cpl_xmemory_ncells);
-
-            if (mode == 2 && cpl_xmemory_ncells > 0) {
-                size_t ii;
-                size_t ntype[4] = {0, 0, 0, 0};
-
-                /* assert( cpl_xmemory_table_size != 0 ); */
-
-                fprintf(stderr,
-                        "Memory allocation [B]:        %zu\n"
-                        "Current table size [pointer]: %zu\n"
-                        "Current table size [B]:       %zu\n",
-                        cpl_xmemory_alloc_ram,
-                        cpl_xmemory_table_size,
-                        cpl_xmemory_table_size * rowsize);
-
-                /* Do not print entire table on fatal error
-                   - it is likely huge */
-                if (cpl_xmemory_fatal == 0)
-                    fprintf(stderr, "#- Active pointer details\n");
-                for (ii=0; ii < cpl_xmemory_table_size; ii++) {
-                    if (cpl_xmemory_p_type[ii] != CPL_XMEMORY_TYPE_FREE) {
-                        ntype[cpl_xmemory_p_type[ii]]++;
-                        if (cpl_xmemory_fatal == 0)
-                            fprintf(stderr, "(%p) - %s() of %zu bytes\n",
-                                    cpl_xmemory_p_val[ii],
-                                    cpl_xmemory_type[cpl_xmemory_p_type[ii]],
-                                    cpl_xmemory_p_size[ii]);
-                    }
-                }
-                fprintf(stderr, "#- Types of active pointers\n");
-                fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[1], ntype[1]);
-                fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[2], ntype[2]);
-                fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[3], ntype[3]);
-            }
-            if (cpl_xmemory_fatal != 0) (void)fflush(stderr);
+        if (mode == 2) {
+            fprintf(stderr,
+                    "Total allocations [pointer]:  %zu\n"
+                    "Peak pointer usage [pointer]: %zu\n"
+                    "Peak memory allocation [B]:   %zu\n"
+                    "Peak table size [pointer]:    %zu\n"
+                    "Peak table size [B]:          %zu\n",
+                    cpl_xmemory_sum_cells, cpl_xmemory_max_cells,
+                    cpl_xmemory_alloc_max, cpl_xmemory_table_size_max,
+                    cpl_xmemory_table_size_max * rowsize);
         }
+        else {
+            fprintf(stderr,
+                    "Total number of allocations"
+#ifdef _OPENMP
+                    /* cpl_xmemory_sum_cells is not updated thread-safely */
+                    " (approximate)"
+#endif
+                    ": %zu\n",
+                    cpl_xmemory_sum_cells);
+            fprintf(stderr,
+                    "Maximum number of pointers"
+#ifdef _OPENMP
+                    /* cpl_xmemory_max_cells is not updated thread-safely */
+                    " (approximate)"
+#endif
+                    ": %zu\n",
+                    cpl_xmemory_max_cells);
+        }
+
+        fprintf(stderr, "#----- Memory Currently Allocated -----\n");
+
+        fprintf(stderr, "Number of active pointers:    %zu\n",
+                cpl_xmemory_ncells);
+
+        if (mode == 2 && cpl_xmemory_ncells > 0) {
+            size_t ii;
+            size_t ntype[4] = { 0, 0, 0, 0 };
+
+            /* assert( cpl_xmemory_table_size != 0 ); */
+
+            fprintf(stderr,
+                    "Memory allocation [B]:        %zu\n"
+                    "Current table size [pointer]: %zu\n"
+                    "Current table size [B]:       %zu\n",
+                    cpl_xmemory_alloc_ram, cpl_xmemory_table_size,
+                    cpl_xmemory_table_size * rowsize);
+
+            /* Do not print entire table on fatal error
+                   - it is likely huge */
+            if (cpl_xmemory_fatal == 0)
+                fprintf(stderr, "#- Active pointer details\n");
+            for (ii = 0; ii < cpl_xmemory_table_size; ii++) {
+                if (cpl_xmemory_p_type[ii] != CPL_XMEMORY_TYPE_FREE) {
+                    ntype[cpl_xmemory_p_type[ii]]++;
+                    if (cpl_xmemory_fatal == 0)
+                        fprintf(stderr, "(%p) - %s() of %zu bytes\n",
+                                cpl_xmemory_p_val[ii],
+                                cpl_xmemory_type[cpl_xmemory_p_type[ii]],
+                                cpl_xmemory_p_size[ii]);
+                }
+            }
+            fprintf(stderr, "#- Types of active pointers\n");
+            fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[1], ntype[1]);
+            fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[2], ntype[2]);
+            fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[3], ntype[3]);
+        }
+        if (cpl_xmemory_fatal != 0)
+            (void)fflush(stderr);
+    }
 
     return;
 }
@@ -676,7 +678,8 @@ void cpl_xmemory_status(int mode)
             -1 if the memory model is off
  */
 /*----------------------------------------------------------------------------*/
-int cpl_xmemory_is_empty(int mode)
+int
+cpl_xmemory_is_empty(int mode)
 {
     if (mode > 0) {
         /*
@@ -685,7 +688,8 @@ int cpl_xmemory_is_empty(int mode)
           assert(cpl_xmemory_ncells == 0 || cpl_xmemory_alloc_ram  > 0);
         */
         return cpl_xmemory_ncells == 0 ? 1 : 0;
-    } else {
+    }
+    else {
         return -1;
     }
 }
@@ -704,31 +708,40 @@ int cpl_xmemory_is_empty(int mode)
 
  */
 /*----------------------------------------------------------------------------*/
-static void cpl_xmemory_init(void)
+static void
+cpl_xmemory_init(void)
 {
-
     if (CPL_XMEMORY_RESIZE_THRESHOLD > 1.0) {
-        fprintf(stderr, "cpl_xmemory fatal error: Memory table resize threshold "
-                CPL_XSTRINGIFY(CPL_XMEMORY_RESIZE_THRESHOLD) " must be less "
-                "than or equal to 1, not "
-                CPL_STRINGIFY(CPL_XMEMORY_RESIZE_THRESHOLD) "\n");
+        fprintf(
+            stderr,
+            "cpl_xmemory fatal error: Memory table resize "
+            "threshold " CPL_XSTRINGIFY(
+                CPL_XMEMORY_RESIZE_THRESHOLD) " must be less "
+                                              "than or equal to 1, "
+                                              "not " CPL_STRINGIFY(CPL_XMEMORY_RESIZE_THRESHOLD) "\n");
         assert(CPL_XMEMORY_RESIZE_THRESHOLD <= 1.0); /* More informative */
 
         abort();
     }
 
     if (CPL_XMEMORY_RESIZE_THRESHOLD <= 0.0) {
-        fprintf(stderr, "cpl_xmemory fatal error: Memory table resize threshold "
-                CPL_XSTRINGIFY(CPL_XMEMORY_RESIZE_THRESHOLD) " must be positive"
-                ", not " CPL_STRINGIFY(CPL_XMEMORY_RESIZE_THRESHOLD) "\n");
+        fprintf(
+            stderr,
+            "cpl_xmemory fatal error: Memory table resize "
+            "threshold " CPL_XSTRINGIFY(
+                CPL_XMEMORY_RESIZE_THRESHOLD) " must be positive"
+                                              ", not " CPL_STRINGIFY(CPL_XMEMORY_RESIZE_THRESHOLD) "\n");
         assert(CPL_XMEMORY_RESIZE_THRESHOLD > 0.0); /* More informative */
         abort();
     }
 
     if (CPL_XMEMORY_RESIZE_FACTOR <= 1.0) {
-        fprintf(stderr, "cpl_xmemory fatal error: Memory table resize factor "
-                CPL_XSTRINGIFY(CPL_XMEMORY_RESIZE_FACTOR) " must be greater "
-                "than 1, not " CPL_STRINGIFY(CPL_XMEMORY_RESIZE_FACTOR) "\n");
+        fprintf(
+            stderr,
+            "cpl_xmemory fatal error: Memory table resize "
+            "factor " CPL_XSTRINGIFY(
+                CPL_XMEMORY_RESIZE_FACTOR) " must be greater "
+                                           "than 1, not " CPL_STRINGIFY(CPL_XMEMORY_RESIZE_FACTOR) "\n");
         assert(CPL_XMEMORY_RESIZE_FACTOR > 1.0); /* More informative */
         abort();
     }
@@ -749,31 +762,32 @@ static void cpl_xmemory_init(void)
 
  */
 /*----------------------------------------------------------------------------*/
-static void cpl_xmemory_init_alloc(void)
+static void
+cpl_xmemory_init_alloc(void)
 {
-
     {
-        cpl_xmemory_p_val  = calloc(cpl_xmemory_table_size, sizeof(void*));
-        cpl_xmemory_p_type = calloc(cpl_xmemory_table_size,
-                                    sizeof(unsigned char));
+        cpl_xmemory_p_val = calloc(cpl_xmemory_table_size, sizeof(void *));
+        cpl_xmemory_p_type =
+            calloc(cpl_xmemory_table_size, sizeof(unsigned char));
         cpl_xmemory_p_size = malloc(cpl_xmemory_table_size * sizeof(size_t));
 
         /* FIXME: pragma omp atomic */
         if (cpl_xmemory_table_size > cpl_xmemory_table_size_max) {
             cpl_xmemory_table_size_max = cpl_xmemory_table_size;
         }
-
     }
 
     if (cpl_xmemory_p_val == NULL || cpl_xmemory_p_size == NULL ||
         cpl_xmemory_p_type == NULL) {
         /* The table could not be allocated */
-        fprintf(stderr, "cpl_xmemory fatal error: calloc() of memory table "
-                "failed with size %zu:\n", cpl_xmemory_table_size);
+        fprintf(stderr,
+                "cpl_xmemory fatal error: calloc() of memory table "
+                "failed with size %zu:\n",
+                cpl_xmemory_table_size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
-        cpl_xmemory_status(1); /* Mode-2 data is invalid! */
-        assert(cpl_xmemory_p_val != NULL);  /* More informative, if enabled */
+        cpl_xmemory_status(1);             /* Mode-2 data is invalid! */
+        assert(cpl_xmemory_p_val != NULL); /* More informative, if enabled */
         assert(cpl_xmemory_p_size != NULL);
         assert(cpl_xmemory_p_type != NULL);
         abort();
@@ -790,18 +804,18 @@ static void cpl_xmemory_init_alloc(void)
 
  */
 /*----------------------------------------------------------------------------*/
-static void cpl_xmemory_resize(void)
+static void
+cpl_xmemory_resize(void)
 {
+    const void **p_val = cpl_xmemory_p_val;
+    size_t *p_size = cpl_xmemory_p_size;
+    unsigned char *p_type = cpl_xmemory_p_type;
+    const size_t old_size = cpl_xmemory_table_size;
+    size_t ii;
 
-    const void   ** p_val    = cpl_xmemory_p_val;
-    size_t        * p_size   = cpl_xmemory_p_size;
-    unsigned char * p_type   = cpl_xmemory_p_type;
-    const size_t    old_size = cpl_xmemory_table_size;
-    size_t          ii;
+    assert(cpl_xmemory_table_size > 0);
 
-    assert( cpl_xmemory_table_size > 0 );
-
-    assert( cpl_xmemory_ncells > 0 );
+    assert(cpl_xmemory_ncells > 0);
 
     cpl_xmemory_table_size = cpl_xmemory_table_size * CPL_XMEMORY_RESIZE_FACTOR;
 
@@ -810,12 +824,14 @@ static void cpl_xmemory_resize(void)
 
     if (cpl_xmemory_table_size <= old_size) {
         /* The table could not be resized */
-        fprintf(stderr, "cpl_xmemory fatal error: Memory table could not be "
-                "resized, %zu < %zu:\n", cpl_xmemory_table_size, old_size);
+        fprintf(stderr,
+                "cpl_xmemory fatal error: Memory table could not be "
+                "resized, %zu < %zu:\n",
+                cpl_xmemory_table_size, old_size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
-        cpl_xmemory_status(1); /* Mode-2 data is invalid! */
-        assert(cpl_xmemory_table_size > old_size);  /* More informative */
+        cpl_xmemory_status(1);                     /* Mode-2 data is invalid! */
+        assert(cpl_xmemory_table_size > old_size); /* More informative */
         abort();
     }
 
@@ -836,7 +852,7 @@ static void cpl_xmemory_resize(void)
         }
     }
 
-    free((void*)p_val);
+    free((void *)p_val);
     free(p_size);
     free(p_type);
 
@@ -851,11 +867,10 @@ static void cpl_xmemory_resize(void)
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-static void cpl_xmemory_end(void)
+inline static void
+cpl_xmemory_end(void)
 {
-
-    assert( cpl_xmemory_ncells == 0 );
+    assert(cpl_xmemory_ncells == 0);
 
     cpl_xmemory_table_size = 0;
 
@@ -884,13 +899,12 @@ static void cpl_xmemory_end(void)
   the passed values are correct!
  */
 /*----------------------------------------------------------------------------*/
-inline
-static void cpl_xmemory_addcell(size_t        pos,
-                                const void  * pointer,
-                                size_t        size,
-                                unsigned char type)
+inline static void
+cpl_xmemory_addcell(size_t pos,
+                    const void *pointer,
+                    size_t size,
+                    unsigned char type)
 {
-
     /* Store information */
     cpl_xmemory_p_val[pos] = pointer;
     cpl_xmemory_p_size[pos] = size;
@@ -917,16 +931,18 @@ static void cpl_xmemory_addcell(size_t        pos,
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-static size_t cpl_xmemory_findcell(const void * ptr)
+inline static size_t
+cpl_xmemory_findcell(const void *ptr)
 {
     const size_t pos = PTR_HASH(ptr);
-    size_t       ii = pos;
+    size_t ii = pos;
 
     /* Locate pointer in main table */
     do {
-        if (cpl_xmemory_p_val[ii] == ptr) return ii; /* Found */
-        if (++ii == cpl_xmemory_table_size) ii = 0; /* Wrap around */
+        if (cpl_xmemory_p_val[ii] == ptr)
+            return ii; /* Found */
+        if (++ii == cpl_xmemory_table_size)
+            ii = 0; /* Wrap around */
     } while (ii != pos);
 
     /* Not found */
@@ -944,17 +960,16 @@ static size_t cpl_xmemory_findcell(const void * ptr)
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-static size_t cpl_xmemory_findfree(const void * ptr)
+inline static size_t
+cpl_xmemory_findfree(const void *ptr)
 {
-
     /* Find an available slot */
     const size_t pos = PTR_HASH(ptr);
 
     /* In comparison with the method of cpl_xmemory_findcell()
        this is faster when the table starts to be full */
-    const void * ppos = memchr(cpl_xmemory_p_type+pos, CPL_XMEMORY_TYPE_FREE,
-                               cpl_xmemory_table_size - pos);
+    const void *ppos = memchr(cpl_xmemory_p_type + pos, CPL_XMEMORY_TYPE_FREE,
+                              cpl_xmemory_table_size - pos);
 
     if (ppos == NULL) {
         ppos = memchr(cpl_xmemory_p_type, CPL_XMEMORY_TYPE_FREE, pos);
@@ -962,7 +977,7 @@ static size_t cpl_xmemory_findfree(const void * ptr)
         if (ppos == NULL) {
             /* No available slot */
             fprintf(stderr, "cpl_xmemory internal, fatal error: "
-                    "Could not find place for new pointer\n");
+                            "Could not find place for new pointer\n");
             cpl_xmemory_fatal = 1;
             cpl_xmemory_status(2);
             assert(ppos != NULL); /* More informative, if enabled */
@@ -984,8 +999,8 @@ static size_t cpl_xmemory_findfree(const void * ptr)
 
  */
 /*----------------------------------------------------------------------------*/
-inline
-static void cpl_xmemory_remcell(size_t pos)
+inline static void
+cpl_xmemory_remcell(size_t pos)
 {
     /* Set pointer to NULL */
     cpl_xmemory_p_val[pos] = NULL;
