@@ -20,13 +20,14 @@
 
 #define TYPE_ADD(a) CONCAT2X(a, PIXEL_TYPE)
 
-static void TYPE_ADD(filter_median_bf)(const PIXEL_TYPE *in,
-                                       PIXEL_TYPE *out,
-                                       unsigned Nx,
-                                       unsigned Ny,
-                                       unsigned Rx,
-                                       unsigned Ry,
-                                       unsigned mode)
+static void
+TYPE_ADD(filter_median_bf)(const PIXEL_TYPE *in,
+                           PIXEL_TYPE *out,
+                           unsigned Nx,
+                           unsigned Ny,
+                           unsigned Rx,
+                           unsigned Ry,
+                           unsigned mode)
 {
     PIXEL_TYPE *data =
         cpl_malloc((size_t)(2 * Rx + 1) * (size_t)(2 * Ry + 1) * sizeof(*data));
@@ -126,14 +127,15 @@ static void TYPE_ADD(filter_median_bf)(const PIXEL_TYPE *in,
 }
 
 
-static void TYPE_ADD(test_cpl_image_filter)(unsigned Nx,
-                                            unsigned Ny,
-                                            unsigned Rx,
-                                            unsigned Ry,
-                                            unsigned filter,
-                                            unsigned border_mode,
-                                            unsigned Nreps1,
-                                            unsigned Nreps2)
+static void
+TYPE_ADD(test_cpl_image_filter)(unsigned Nx,
+                                unsigned Ny,
+                                unsigned Rx,
+                                unsigned Ry,
+                                unsigned filter,
+                                unsigned border_mode,
+                                unsigned Nreps1,
+                                unsigned Nreps2)
 {
     PIXEL_TYPE *in = cpl_malloc((size_t)Nx * (size_t)Ny * sizeof(*in));
     /* Too large in crop mode */
@@ -262,13 +264,14 @@ static void TYPE_ADD(test_cpl_image_filter)(unsigned Nx,
    @see uves_filter_image_average()
 */
 /*----------------------------------------------------------------------------*/
-static void TYPE_ADD(image_filter_average_ref)(PIXEL_TYPE *out,
-                                               const PIXEL_TYPE *in,
-                                               int nx,
-                                               int ny,
-                                               int hsizex,
-                                               int hsizey,
-                                               unsigned border_mode)
+static void
+TYPE_ADD(image_filter_average_ref)(PIXEL_TYPE *out,
+                                   const PIXEL_TYPE *in,
+                                   int nx,
+                                   int ny,
+                                   int hsizex,
+                                   int hsizey,
+                                   unsigned border_mode)
 {
     PIXEL_TYPE *aux = calloc((nx + 1) * (ny + 1), sizeof(PIXEL_TYPE));
     int i;
@@ -367,13 +370,14 @@ static void TYPE_ADD(image_filter_average_ref)(PIXEL_TYPE *out,
    @see uves_filter_image_average()
 */
 /*----------------------------------------------------------------------------*/
-static void TYPE_ADD(image_filter_average_bf)(PIXEL_TYPE *out,
-                                              const PIXEL_TYPE *in,
-                                              int Nx,
-                                              int Ny,
-                                              int hsizex,
-                                              int hsizey,
-                                              unsigned border_mode)
+static void
+TYPE_ADD(image_filter_average_bf)(PIXEL_TYPE *out,
+                                  const PIXEL_TYPE *in,
+                                  int Nx,
+                                  int Ny,
+                                  int hsizex,
+                                  int hsizey,
+                                  unsigned border_mode)
 {
     int y;
 
