@@ -529,7 +529,7 @@ main(void)
             for (ibpp = 0; ibpp < nbpp; ibpp++) {
                 cpl_propertylist *plist = cpl_propertylist_new();
                 const char *sval = cpl_type_get_name(bpps[ibpp]);
-                int j;
+                int j, ibbp2;
 
                 cpl_test_nonnull(sval);
 
@@ -605,7 +605,26 @@ main(void)
                                       NULL, CPL_IO_APPEND);
                 cpl_test_eq_error(code, CPL_ERROR_ILLEGAL_INPUT);
 
-                cpl_test_eq(cpl_fits_count_extensions(FILENAME), ibpp);
+                ibbp2 = cpl_fits_count_extensions(FILENAME);
+                cpl_test_error(CPL_ERROR_NONE);
+                cpl_test_eq(ibbp2, ibpp);
+
+                /* Try to read from beyond EOF */
+                nullimg =
+                    cpl_image_load(FILENAME, CPL_TYPE_UNSPECIFIED, 0, ibpp + 1);
+                cpl_test_error(CPL_ERROR_BAD_FILE_FORMAT);
+                cpl_test_null(nullimg);
+
+                /* Negative extension number */
+                nullimg = cpl_image_load(FILENAME, CPL_TYPE_UNSPECIFIED, 0, -1);
+                cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
+                cpl_test_null(nullimg);
+
+                /* Try to read an invalid type */
+                nullimg =
+                    cpl_image_load(FILENAME, CPL_TYPE_DOUBLE_COMPLEX, 0, ibpp);
+                cpl_test_error(CPL_ERROR_INVALID_TYPE);
+                cpl_test_null(nullimg);
 
                 for (j = 0; j < 1; j++) { /* Only 1 iteration, no append */
                     /* Tests for no-casting type */
