@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,22 +54,48 @@
                  Function prototypes
  ----------------------------------------------------------------------------*/
 
+static void cpl_io_fits_test_all(const char *);
 static void cpl_io_fits_test_many(int);
-static void cpl_io_fits_test_fulldisk_table(const char*);
+static void cpl_io_fits_test_fulldisk_table(const char *);
 
 /*-----------------------------------------------------------------------------
                                   Main
  -----------------------------------------------------------------------------*/
-int main(int argc, char *argv[])
+int
+main(int argc, char *argv[])
 {
-    cpl_boolean    do_bench;
-    int            next = NEXT;
-    int            j;
-
-
-
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
 
+    if (cpl_io_fits_is_enabled()) {
+        cpl_io_fits_test_all(argc == 2 ? argv[1] : NULL);
+    }
+    else {
+        cpl_msg_warning(cpl_func,
+                        "Skipping tests: CPL FITS caching is not enabled");
+        cpl_msg_warning(cpl_func, "To test CPL FITS caching rerun with "
+                                  "environment variable: CPL_IO_MODE=1");
+    }
+
+    /* End of tests */
+    return cpl_test_end(0);
+}
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief       Perform all tests
+  @param       Root string, or NULL
+  @return void
+ */
+/*----------------------------------------------------------------------------*/
+void
+cpl_io_fits_test_all(const char *root)
+{
+    cpl_boolean do_bench;
+    cpl_size max_files;
+    int next = NEXT;
+    int j;
+
     do_bench = cpl_msg_get_level() <= CPL_MSG_INFO ? CPL_TRUE : CPL_FALSE;
 
     if (do_bench)
@@ -77,19 +103,23 @@ int main(int argc, char *argv[])
 
     /* Insert tests below */
 
-    if (argc == 2) {
-        cpl_io_fits_test_fulldisk_table(argv[1]);
+    max_files = cpl_io_get_max_open();
+    cpl_test_error(CPL_ERROR_NONE);
+
+    cpl_msg_info(cpl_func, "Maximum number of files kept open: %d",
+                 (int)max_files);
+
+    if (root != NULL) {
+        cpl_io_fits_test_fulldisk_table(root);
     }
 
-    cpl_io_fits_test_many(do_bench
-                          ? 1 + CPL_IO_FITS_MAX_OPEN
-                          : 1 + CPL_IO_FITS_MAX_OPEN/3);
+    cpl_io_fits_test_many(1 + max_files);
 
 #ifdef _OPENMP
 #pragma omp parallel for private(j)
 #endif
     for (j = 0; j < NFILE; j++) {
-        char * filename = cpl_sprintf(BASENAME "-%d.fits", j + 1);
+        char *filename = cpl_sprintf(BASENAME "-%d.fits", j + 1);
         int base = j * next * 10; /* Assume at most 10 load-loops */
         int i;
 
@@ -102,8 +132,8 @@ int main(int argc, char *argv[])
 #endif
         for (i = 0; i <= next; i++) {
             cpl_error_code myerror;
-            cpl_image * myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
-            cpl_propertylist * plist = cpl_propertylist_new();
+            cpl_image *myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
+            cpl_propertylist *plist = cpl_propertylist_new();
 
             myerror = cpl_propertylist_append_int(plist, "MYINT", i + base);
             cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -121,7 +151,6 @@ int main(int argc, char *argv[])
             cpl_test_eq_error(myerror, CPL_ERROR_NONE);
             cpl_image_delete(myimage);
             cpl_propertylist_delete(plist);
-
         }
 
         cpl_test_eq(cpl_fits_count_extensions(filename), next);
@@ -132,8 +161,8 @@ int main(int argc, char *argv[])
 #endif
         for (i = 0; i <= next; i++) {
             int is_bad;
-            cpl_image * myimage = cpl_image_load(filename, CPL_TYPE_INT, 0, i);
-            cpl_propertylist * plist;
+            cpl_image *myimage = cpl_image_load(filename, CPL_TYPE_INT, 0, i);
+            cpl_propertylist *plist;
 
             cpl_test_error(CPL_ERROR_NONE);
             cpl_test_nonnull(myimage);
@@ -162,8 +191,8 @@ int main(int argc, char *argv[])
 #endif
         for (i = 0; i <= next; i++) {
             cpl_error_code myerror;
-            cpl_image * myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
-            cpl_propertylist * plist = cpl_propertylist_new();
+            cpl_image *myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
+            cpl_propertylist *plist = cpl_propertylist_new();
 
             myerror = cpl_propertylist_append_int(plist, "MYINT", i + base);
             cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -175,15 +204,14 @@ int main(int argc, char *argv[])
 #pragma omp ordered
 #endif
             {
-                myerror = cpl_image_save(myimage, filename, CPL_TYPE_INT, plist,
-                                         (i & 1) ? CPL_IO_EXTEND
-                                         : CPL_IO_CREATE);
+                myerror =
+                    cpl_image_save(myimage, filename, CPL_TYPE_INT, plist,
+                                   (i & 1) ? CPL_IO_EXTEND : CPL_IO_CREATE);
             }
             cpl_test_eq_error(myerror, CPL_ERROR_NONE);
 
             cpl_image_delete(myimage);
             cpl_propertylist_delete(plist);
-
         }
 
         cpl_test_eq(cpl_fits_count_extensions(filename), next & 1);
@@ -194,14 +222,14 @@ int main(int argc, char *argv[])
 #endif
         for (i = 0; i <= (next & 1); i++) {
             int is_bad;
-            cpl_image * myimage = cpl_image_load(filename, CPL_TYPE_INT, 0, i);
-            cpl_propertylist * plist;
+            cpl_image *myimage = cpl_image_load(filename, CPL_TYPE_INT, 0, i);
+            cpl_propertylist *plist;
 
 
             cpl_test_error(CPL_ERROR_NONE);
             cpl_test_nonnull(myimage);
-            cpl_test_eq(cpl_image_get(myimage, 1, 1, &is_bad), i + (next & ~1)
-                                                               + base);
+            cpl_test_eq(cpl_image_get(myimage, 1, 1, &is_bad),
+                        i + (next & ~1) + base);
             cpl_test_zero(is_bad);
             cpl_image_delete(myimage);
 
@@ -213,7 +241,6 @@ int main(int argc, char *argv[])
                         i + (next & ~1) + base);
 
             cpl_propertylist_delete(plist);
-
         }
 
         base += next;
@@ -226,8 +253,8 @@ int main(int argc, char *argv[])
         for (i = 0; i <= next; i++) {
             int is_bad;
             cpl_error_code myerror;
-            cpl_image * myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
-            cpl_propertylist * plist = cpl_propertylist_new();
+            cpl_image *myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
+            cpl_propertylist *plist = cpl_propertylist_new();
 
             myerror = cpl_propertylist_append_int(plist, "MYINT", i + base);
             cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -255,7 +282,6 @@ int main(int argc, char *argv[])
                 cpl_propertylist_delete(plist);
                 plist = cpl_propertylist_load(filename, i);
                 cpl_test_error(CPL_ERROR_NONE);
-
             }
 
             cpl_test_nonnull(myimage);
@@ -267,7 +293,6 @@ int main(int argc, char *argv[])
 
             cpl_image_delete(myimage);
             cpl_propertylist_delete(plist);
-
         }
 
         cpl_test_eq(cpl_fits_count_extensions(filename), next);
@@ -283,56 +308,54 @@ int main(int argc, char *argv[])
 #ifdef _OPENMP
 #pragma omp ordered
 #endif
-            {
-                if (i & 1) {
-                    if (i > 2) {
-                        /* Read the previously written extension */
-                        const int i2 = i / 2 - 1;
-                        int is_bad;
-                        cpl_propertylist * plist;
-                        cpl_image * myimage = cpl_image_load(filename,
-                                                             CPL_TYPE_INT,
-                                                             0, i2);
+        {
+            if (i & 1) {
+                if (i > 2) {
+                    /* Read the previously written extension */
+                    const int i2 = i / 2 - 1;
+                    int is_bad;
+                    cpl_propertylist *plist;
+                    cpl_image *myimage =
+                        cpl_image_load(filename, CPL_TYPE_INT, 0, i2);
 
-                        cpl_test_error(CPL_ERROR_NONE);
-                        cpl_test_nonnull(myimage);
-                        cpl_test_eq(cpl_image_get(myimage, 1, 1, &is_bad),
-                                    i2 + base);
-                        cpl_test_zero(is_bad);
-                        cpl_image_delete(myimage);
-
-                        plist = cpl_propertylist_load(filename, i2);
-                        cpl_test_error(CPL_ERROR_NONE);
-
-                        cpl_test_nonnull(plist);
-                        cpl_test_eq(cpl_propertylist_get_int(plist, "MYINT"),
-                                    i2 + base);
-
-                        cpl_propertylist_delete(plist);
-                    }
-
-                } else {
-                    cpl_error_code myerror;
-                    cpl_image * myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
-                    cpl_propertylist * plist = cpl_propertylist_new();
-
-                    myerror = cpl_propertylist_append_int(plist, "MYINT",
-                                                          i/2 + base);
-                    cpl_test_eq_error(myerror, CPL_ERROR_NONE);
-
-                    myerror = cpl_image_add_scalar(myimage, i/2 + base);
-                    cpl_test_eq_error(myerror, CPL_ERROR_NONE);
-
-                    cpl_test_eq(i, i);
-                    myerror = cpl_image_save(myimage, filename,
-                                             CPL_TYPE_INT, plist,
-                                             i ? CPL_IO_EXTEND : CPL_IO_CREATE);
-
-                    cpl_test_eq_error(myerror, CPL_ERROR_NONE);
+                    cpl_test_error(CPL_ERROR_NONE);
+                    cpl_test_nonnull(myimage);
+                    cpl_test_eq(cpl_image_get(myimage, 1, 1, &is_bad),
+                                i2 + base);
+                    cpl_test_zero(is_bad);
                     cpl_image_delete(myimage);
+
+                    plist = cpl_propertylist_load(filename, i2);
+                    cpl_test_error(CPL_ERROR_NONE);
+
+                    cpl_test_nonnull(plist);
+                    cpl_test_eq(cpl_propertylist_get_int(plist, "MYINT"),
+                                i2 + base);
+
                     cpl_propertylist_delete(plist);
                 }
             }
+            else {
+                cpl_error_code myerror;
+                cpl_image *myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
+                cpl_propertylist *plist = cpl_propertylist_new();
+
+                myerror =
+                    cpl_propertylist_append_int(plist, "MYINT", i / 2 + base);
+                cpl_test_eq_error(myerror, CPL_ERROR_NONE);
+
+                myerror = cpl_image_add_scalar(myimage, i / 2 + base);
+                cpl_test_eq_error(myerror, CPL_ERROR_NONE);
+
+                cpl_test_eq(i, i);
+                myerror = cpl_image_save(myimage, filename, CPL_TYPE_INT, plist,
+                                         i ? CPL_IO_EXTEND : CPL_IO_CREATE);
+
+                cpl_test_eq_error(myerror, CPL_ERROR_NONE);
+                cpl_image_delete(myimage);
+                cpl_propertylist_delete(plist);
+            }
+        }
 
         cpl_test_eq(cpl_fits_count_extensions(filename), next);
 
@@ -346,8 +369,8 @@ int main(int argc, char *argv[])
         for (i = 0; i <= next; i++) {
             int is_bad;
             cpl_error_code myerror;
-            cpl_image * myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
-            cpl_propertylist * plist = cpl_propertylist_new();
+            cpl_image *myimage = cpl_image_new(1, 1, CPL_TYPE_INT);
+            cpl_propertylist *plist = cpl_propertylist_new();
 
             myerror = cpl_propertylist_append_int(plist, "MYINT", i + base);
             cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -359,9 +382,9 @@ int main(int argc, char *argv[])
 #pragma omp ordered
 #endif
             {
-                myerror = cpl_image_save(myimage, filename, CPL_TYPE_INT, plist,
-                                         (i & 1) ? CPL_IO_EXTEND
-                                         : CPL_IO_CREATE);
+                myerror =
+                    cpl_image_save(myimage, filename, CPL_TYPE_INT, plist,
+                                   (i & 1) ? CPL_IO_EXTEND : CPL_IO_CREATE);
                 cpl_test_eq_error(myerror, CPL_ERROR_NONE);
 
                 /* Make sure to jump around between the extensions */
@@ -375,7 +398,6 @@ int main(int argc, char *argv[])
                 cpl_propertylist_delete(plist);
                 plist = cpl_propertylist_load(filename, i & 1);
                 cpl_test_error(CPL_ERROR_NONE);
-
             }
 
             cpl_test_nonnull(myimage);
@@ -387,28 +409,24 @@ int main(int argc, char *argv[])
             cpl_test_eq(cpl_propertylist_get_int(plist, "MYINT"), i + base);
 
             cpl_propertylist_delete(plist);
-
         }
 
         cpl_test_eq(cpl_fits_count_extensions(filename), next & 1);
 
-        cpl_free((void*)filename);
+        cpl_free((void *)filename);
     }
 
-    if (cpl_fits_get_mode() | CPL_FITS_START_CACHING) {
+    if (cpl_fits_get_mode() & CPL_FITS_START_CACHING) {
         cpl_error_code myerror;
         myerror = cpl_fits_set_mode(CPL_FITS_STOP_CACHING);
         cpl_test_eq_error(myerror, CPL_ERROR_NONE);
     }
 
     for (j = 0; j < NFILE; j++) {
-        char * filename = cpl_sprintf(BASENAME "-%d.fits", j + 1);
+        char *filename = cpl_sprintf(BASENAME "-%d.fits", j + 1);
         cpl_test_zero(remove(filename));
         cpl_free(filename);
     }
-
-    /* End of tests */
-    return cpl_test_end(0);
 }
 
 
@@ -419,17 +437,17 @@ int main(int argc, char *argv[])
   @return   void
  */
 /*----------------------------------------------------------------------------*/
-static void cpl_io_fits_test_many(int n)
+static void
+cpl_io_fits_test_many(int n)
 {
-
-    cpl_propertylist * plist = cpl_propertylist_new();
+    cpl_propertylist *plist = cpl_propertylist_new();
     const cpl_fits_mode iomode = cpl_fits_get_mode();
 
     cpl_msg_info(cpl_func, "Testing I/O-mode %d <=> %d with %d file(s)",
                  (int)iomode, (int)CPL_FITS_START_CACHING, n);
 
     for (int i = 0; i < n; i++) {
-        char * filename = cpl_sprintf(BASENAME "-%d.fits", i + 1);
+        char *filename = cpl_sprintf(BASENAME "-%d.fits", i + 1);
         cpl_error_code myerror;
         myerror = cpl_propertylist_update_int(plist, "MYINT", i);
         cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -445,23 +463,22 @@ static void cpl_io_fits_test_many(int n)
         cpl_test_eq(cpl_propertylist_get_int(plist, "MYINT"), i);
 
         cpl_free(filename);
-
     }
 
     cpl_propertylist_delete(plist);
 
-    if (iomode | CPL_FITS_START_CACHING) {
+    if (iomode & CPL_FITS_START_CACHING) {
         cpl_error_code myerror;
         myerror = cpl_fits_set_mode(CPL_FITS_STOP_CACHING);
         cpl_test_eq_error(myerror, CPL_ERROR_NONE);
     }
 
     for (int i = 0; i < n; i++) {
-        char * filename = cpl_sprintf(BASENAME "-%d.fits", i + 1);
+        char *filename = cpl_sprintf(BASENAME "-%d.fits", i + 1);
         cpl_test_zero(remove(filename));
         cpl_free(filename);
     }
-    if (iomode | CPL_FITS_START_CACHING) {
+    if (iomode & CPL_FITS_STOP_CACHING) {
         cpl_error_code myerror;
         myerror = cpl_fits_set_mode(iomode);
         cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -471,15 +488,17 @@ static void cpl_io_fits_test_many(int n)
 
 /*----------------------------------------------------------------------------*/
 /**
+  @internal
   @brief       Test I/O on a user specified file system (of limited size)
   @param  root The name of the file system to fill up
   @return void
  */
 /*----------------------------------------------------------------------------*/
-static void cpl_io_fits_test_fulldisk_table(const char* root)
+static void
+cpl_io_fits_test_fulldisk_table(const char *root)
 {
-    cpl_table*     mytab = cpl_table_new(1000);
-    char*          filename = cpl_sprintf("%s/" BASENAME ".fits", root);
+    cpl_table *mytab = cpl_table_new(1000);
+    char *filename = cpl_sprintf("%s/" BASENAME ".fits", root);
     const cpl_fits_mode iomode = cpl_fits_get_mode();
     cpl_error_code code;
 
@@ -506,14 +525,17 @@ static void cpl_io_fits_test_fulldisk_table(const char* root)
     if (cpl_test_get_failed() > 0) {
         cpl_msg_warning(cpl_func, "Test failed, not deleting file:: %s",
                         filename);
-    } else if (remove(filename) != 0) {
-        cpl_msg_info(cpl_func, "The failure-test file has already been deleted: "
-                     "%s", filename);
+    }
+    else if (remove(filename) != 0) {
+        cpl_msg_info(cpl_func,
+                     "The failure-test file has already been deleted: "
+                     "%s",
+                     filename);
     }
 
     cpl_table_delete(mytab);
 
-    if (iomode | CPL_FITS_START_CACHING) {
+    if (iomode & CPL_FITS_START_CACHING) {
         cpl_error_code myerror;
         myerror = cpl_fits_set_mode(CPL_FITS_STOP_CACHING);
         cpl_test_eq_error(myerror, CPL_ERROR_NONE);
@@ -521,7 +543,7 @@ static void cpl_io_fits_test_fulldisk_table(const char* root)
 
     cpl_test_zero(remove(filename));
 
-    if (iomode | CPL_FITS_START_CACHING) {
+    if (iomode & CPL_FITS_STOP_CACHING) {
         cpl_error_code myerror;
         myerror = cpl_fits_set_mode(iomode);
         cpl_test_eq_error(myerror, CPL_ERROR_NONE);
