@@ -210,8 +210,8 @@ cpl_apertures_dump(const cpl_apertures *self, FILE *fp)
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Compute statistics on selected apertures
-  @param    self    Reference image
-  @param    lab     Labelized image (of type CPL_TYPE_INT)
+  @param    in_image Reference image
+  @param    lab      Labelized image (of type CPL_TYPE_INT)
   @return   An CPL apertures object or @em NULL on error
   @note The returned object must be deleted using cpl_apertures_delete().
   @see cpl_image_labelise_mask_create()
@@ -240,10 +240,10 @@ cpl_apertures_dump(const cpl_apertures *self, FILE *fp)
  */
 /*----------------------------------------------------------------------------*/
 cpl_apertures *
-cpl_apertures_new_from_image(const cpl_image *self, const cpl_image *lab)
+cpl_apertures_new_from_image(const cpl_image *in_image, const cpl_image *lab)
 {
     cpl_apertures *aperts =
-        cpl_apertures_new_from_image_(self, lab, 0, CPL_TRUE);
+        cpl_apertures_new_from_image_(in_image, lab, 0, CPL_TRUE);
 
     if (aperts == NULL)
         (void)cpl_error_set_where_();
@@ -1057,7 +1057,7 @@ cpl_apertures_sort_by_flux(cpl_apertures *self)
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Simple detection of apertures in an image
-  @param    self        The image to process
+  @param    in_image    The image to process
   @param    sigmas      Positive, decreasing sigmas to apply
   @param    pisigma     Index of the sigma that was used or unchanged on error
   @return   The detected apertures or NULL on error
@@ -1071,7 +1071,7 @@ cpl_apertures_sort_by_flux(cpl_apertures *self)
  */
 /*----------------------------------------------------------------------------*/
 cpl_apertures *
-cpl_apertures_extract(const cpl_image *self,
+cpl_apertures_extract(const cpl_image *in_image,
                       const cpl_vector *sigmas,
                       cpl_size *pisigma)
 {
@@ -1080,7 +1080,7 @@ cpl_apertures_extract(const cpl_image *self,
     const cpl_size n = cpl_vector_get_size(sigmas);
     cpl_size i;
 
-    cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(in_image != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(sigmas != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
     for (i = 0; i < n; i++) {
@@ -1090,7 +1090,7 @@ cpl_apertures_extract(const cpl_image *self,
             break;
 
         /* Apply the detection  */
-        aperts = cpl_apertures_extract_sigma(self, sigma);
+        aperts = cpl_apertures_extract_sigma(in_image, sigma);
         if (aperts != NULL)
             break;
     }
@@ -1109,7 +1109,7 @@ cpl_apertures_extract(const cpl_image *self,
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Simple detection of apertures in an image window
-  @param    self        The image to process
+  @param    in_image    The image to process
   @param    sigmas      Positive, decreasing sigmas to apply
   @param    llx         Lower left x position (FITS convention)
   @param    lly         Lower left y position (FITS convention)
@@ -1122,7 +1122,7 @@ cpl_apertures_extract(const cpl_image *self,
  */
 /*----------------------------------------------------------------------------*/
 cpl_apertures *
-cpl_apertures_extract_window(const cpl_image *self,
+cpl_apertures_extract_window(const cpl_image *in_image,
                              const cpl_vector *sigmas,
                              cpl_size llx,
                              cpl_size lly,
@@ -1135,11 +1135,11 @@ cpl_apertures_extract_window(const cpl_image *self,
     cpl_size i;
 
     /* Test entries */
-    cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(in_image != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(sigmas != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
     /* Extract the subwindow - and check entries */
-    extracted = cpl_image_extract(self, llx, lly, urx, ury);
+    extracted = cpl_image_extract(in_image, llx, lly, urx, ury);
     cpl_ensure(extracted, cpl_error_get_code(), NULL);
 
     /* Get the apertures */
@@ -1173,7 +1173,7 @@ cpl_apertures_extract_window(const cpl_image *self,
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Simple apertures creation from a user supplied selection mask
-  @param    self    The image to process
+  @param    in_image   The image to process
   @param    selection  The mask of selected pixels
   @return   The list of detected apertures or NULL if nothing detected or on
             error.
@@ -1193,7 +1193,7 @@ cpl_apertures_extract_window(const cpl_image *self,
  */
 /*----------------------------------------------------------------------------*/
 cpl_apertures *
-cpl_apertures_extract_mask(const cpl_image *self, const cpl_mask *selection)
+cpl_apertures_extract_mask(const cpl_image *in_image, const cpl_mask *selection)
 {
     cpl_errorstate prestate = cpl_errorstate_get();
     cpl_apertures *aperts = NULL;
@@ -1204,7 +1204,7 @@ cpl_apertures_extract_mask(const cpl_image *self, const cpl_mask *selection)
     if (labels != NULL && nlabels > 0) {
         /* Create the detected apertures list */
         aperts =
-            cpl_apertures_new_from_image_(self, labels, nlabels, CPL_FALSE);
+            cpl_apertures_new_from_image_(in_image, labels, nlabels, CPL_FALSE);
     }
 
     if (aperts == NULL) {
@@ -1221,8 +1221,8 @@ cpl_apertures_extract_mask(const cpl_image *self, const cpl_mask *selection)
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Simple apertures detection in an image using a provided sigma
-  @param    self    The image to process
-  @param    sigma   Detection level
+  @param    in_image The image to process
+  @param    sigma    Detection level
   @return   The list of detected apertures or NULL on error
   @note In order to avoid (the potentially many) detections of small objects the
   mask of detected pixels is subjected to a 3x3 morphological opening filter.
@@ -1241,7 +1241,7 @@ cpl_apertures_extract_mask(const cpl_image *self, const cpl_mask *selection)
  */
 /*----------------------------------------------------------------------------*/
 cpl_apertures *
-cpl_apertures_extract_sigma(const cpl_image *self, double sigma)
+cpl_apertures_extract_sigma(const cpl_image *in_image, double sigma)
 {
     double median, med_dist;
     double threshold;
@@ -1249,15 +1249,15 @@ cpl_apertures_extract_sigma(const cpl_image *self, double sigma)
     cpl_apertures *aperts = NULL;
 
     /* Check entries */
-    cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(in_image != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(sigma > 0.0, CPL_ERROR_ILLEGAL_INPUT, NULL);
 
     /* Compute the threshold */
-    median = cpl_image_get_median_dev(self, &med_dist);
+    median = cpl_image_get_median_dev(in_image, &med_dist);
     threshold = median + sigma * med_dist;
 
     /* Binarise the image */
-    selection = cpl_mask_threshold_image_create(self, threshold, DBL_MAX);
+    selection = cpl_mask_threshold_image_create(in_image, threshold, DBL_MAX);
     if (selection != NULL) {
         /* Use a morphological opening to remove the single pixel detections */
         cpl_mask *kernel = cpl_mask_new(3, 3);
@@ -1270,7 +1270,7 @@ cpl_apertures_extract_sigma(const cpl_image *self, double sigma)
 
         if (!error) {
             /* Create the detected apertures list */
-            aperts = cpl_apertures_extract_mask(self, selection);
+            aperts = cpl_apertures_extract_mask(in_image, selection);
         }
 
         cpl_mask_delete(selection);
@@ -1287,8 +1287,8 @@ cpl_apertures_extract_sigma(const cpl_image *self, double sigma)
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Compute FWHM values in x and y for a list of apertures
-  @param    self    The image to process
-  @param    aperts  The list of apertures
+  @param    in_image The image to process
+  @param    aperts   The list of apertures
   @return   A newly allocated object containing the fwhms in x and y or NULL
   @see cpl_image_get_fwhm()
   @deprecated Replace this call with a loop over cpl_image_get_fwhm()
@@ -1296,7 +1296,7 @@ cpl_apertures_extract_sigma(const cpl_image *self, double sigma)
  */
 /*----------------------------------------------------------------------------*/
 cpl_bivector *
-cpl_apertures_get_fwhm(const cpl_image *self, const cpl_apertures *aperts)
+cpl_apertures_get_fwhm(const cpl_image *in_image, const cpl_apertures *aperts)
 {
     cpl_errorstate prevstate = cpl_errorstate_get();
     cpl_bivector *fwhms;
@@ -1306,7 +1306,7 @@ cpl_apertures_get_fwhm(const cpl_image *self, const cpl_apertures *aperts)
     cpl_size i, nok = 0;
 
 
-    cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(in_image != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(aperts != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
     naperts = cpl_apertures_get_size(aperts);
@@ -1321,7 +1321,7 @@ cpl_apertures_get_fwhm(const cpl_image *self, const cpl_apertures *aperts)
     /* Compute FWHM on all apertures */
     for (i = 0; i < naperts; i++) {
         const cpl_error_code error =
-            cpl_image_get_fwhm(self,
+            cpl_image_get_fwhm(in_image,
                                (cpl_size)cpl_apertures_get_pos_x(aperts, i + 1),
                                (cpl_size)cpl_apertures_get_pos_y(aperts, i + 1),
                                &(fwhms_x[i]), &(fwhms_y[i]));
@@ -1412,7 +1412,7 @@ cpl_apertures_new(cpl_size naperts)
 /**
   @internal
   @brief  Compute statistics on selected apertures
-  @param  self      Reference image
+  @param  in_image  Reference image
   @param  lab       Labelized image (of type CPL_TYPE_INT)
   @param  maperts   Number of apertures, or zero for unknown
   @param  bpm_check Iff true, any bpms must be deselected from the labels
@@ -1423,7 +1423,7 @@ cpl_apertures_new(cpl_size naperts)
  */
 /*----------------------------------------------------------------------------*/
 cpl_apertures *
-cpl_apertures_new_from_image_(const cpl_image *self,
+cpl_apertures_new_from_image_(const cpl_image *in_image,
                               const cpl_image *lab,
                               cpl_size maperts,
                               cpl_boolean bpm_check)
@@ -1438,13 +1438,13 @@ cpl_apertures_new_from_image_(const cpl_image *self,
     const int *plab;
     double *medians;
     cpl_size *medianc;
-    const cpl_size nx = cpl_image_get_size_x(self);
-    const cpl_size ny = cpl_image_get_size_y(self);
+    const cpl_size nx = cpl_image_get_size_x(in_image);
+    const cpl_size ny = cpl_image_get_size_y(in_image);
     const double ep = 1e-10;
     cpl_size i, j, k;
 
     /* Test entries */
-    cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
+    cpl_ensure(in_image != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(lab != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(cpl_image_get_type(lab) == CPL_TYPE_INT, CPL_ERROR_TYPE_MISMATCH,
                NULL);
@@ -1454,7 +1454,7 @@ cpl_apertures_new_from_image_(const cpl_image *self,
                NULL);
 
     if (bpm_check) {
-        const cpl_mask *bpm = cpl_image_get_bpm_const(self);
+        const cpl_mask *bpm = cpl_image_get_bpm_const(in_image);
 
         if (bpm != NULL && !cpl_mask_is_empty(bpm)) {
             /* Set the bad pixels of the input image to 0 in the lab image */
@@ -1478,9 +1478,9 @@ cpl_apertures_new_from_image_(const cpl_image *self,
     }
 
     /* Convert input image in a double image */
-    dimage = cpl_image_get_type(self) == CPL_TYPE_DOUBLE
-                 ? self
-                 : (cimage = cpl_image_cast(self, CPL_TYPE_DOUBLE));
+    dimage = cpl_image_get_type(in_image) == CPL_TYPE_DOUBLE
+                 ? in_image
+                 : (cimage = cpl_image_cast(in_image, CPL_TYPE_DOUBLE));
 
     if (dimage == NULL) {
         cpl_image_delete(labcopy);
