@@ -191,7 +191,7 @@ cpl_flux_get_noise_window(const cpl_image *diff,
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Compute the bias in a rectangle.
-  @param    diff        Input image, usually a difference frame.
+  @param    bias_image  Input bias image
   @param    zone_def    Zone where the bias is to be computed.
   @param    ron_hsize   to specify half size of squares (<0 to use default)
   @param    ron_nsamp   to specify the nb of samples (<0 to use default)
@@ -203,26 +203,27 @@ cpl_flux_get_noise_window(const cpl_image *diff,
  */
 /*----------------------------------------------------------------------------*/
 cpl_error_code
-cpl_flux_get_bias_window(const cpl_image *diff,
+cpl_flux_get_bias_window(const cpl_image *bias_image,
                          const cpl_size *zone_def,
                          cpl_size ron_hsize,
                          cpl_size ron_nsamp,
                          double *bias,
                          double *error)
 {
-    return cpl_flux_get_window(diff, zone_def, ron_hsize, ron_nsamp, NULL, NULL,
-                               bias, error)
+    return cpl_flux_get_window(bias_image, zone_def, ron_hsize, ron_nsamp, NULL,
+                               NULL, bias, error)
                ? cpl_error_set_where_()
                : CPL_ERROR_NONE;
 }
 
 /*----------------------------------------------------------------------------*/
 /*
+  @internal
   @brief    Internal function, wrapped by cpl_flux_get_{noise,bias}_window().
  */
 /*----------------------------------------------------------------------------*/
 static cpl_error_code
-cpl_flux_get_window(const cpl_image *diff,
+cpl_flux_get_window(const cpl_image *self,
                     const cpl_size *zone_def,
                     cpl_size ron_hsize,
                     cpl_size ron_nsamp,
@@ -246,7 +247,7 @@ cpl_flux_get_window(const cpl_image *diff,
     cpl_size i;
 
     /* Test entries */
-    cpl_ensure_code(diff != NULL, CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(self != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(noise != NULL || bias != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(nsamples > 0, CPL_ERROR_ILLEGAL_INPUT);
 
@@ -259,9 +260,9 @@ cpl_flux_get_window(const cpl_image *diff,
     }
     else {
         rect[0] = hsize + 1;                              /* xmin */
-        rect[1] = cpl_image_get_size_x(diff) - hsize - 1; /* xmax */
+        rect[1] = cpl_image_get_size_x(self) - hsize - 1; /* xmax */
         rect[2] = hsize + 1;                              /* ymin */
-        rect[3] = cpl_image_get_size_y(diff) - hsize - 1; /* ymax */
+        rect[3] = cpl_image_get_size_y(self) - hsize - 1; /* ymax */
     }
 
     cpl_ensure_code(rect[0] < rect[1] && rect[2] < rect[3],
@@ -294,10 +295,10 @@ cpl_flux_get_window(const cpl_image *diff,
         zone[2] = (cpl_size)py[i + 1] - hsize;
         zone[3] = (cpl_size)py[i + 1] + hsize;
         if (noise)
-            pr1[i] = cpl_image_get_stdev_window(diff, zone[0], zone[2], zone[1],
+            pr1[i] = cpl_image_get_stdev_window(self, zone[0], zone[2], zone[1],
                                                 zone[3]);
         if (bias)
-            pr2[i] = cpl_image_get_mean_window(diff, zone[0], zone[2], zone[1],
+            pr2[i] = cpl_image_get_mean_window(self, zone[0], zone[2], zone[1],
                                                zone[3]);
     }
     cpl_bivector_delete(sample_reg);
@@ -550,6 +551,7 @@ cpl_detector_interpolate_rejected(cpl_image *self)
 
 /*----------------------------------------------------------------------------*/
 /*
+  @internal
   @brief    Generate points with a Poisson scattering property in a rectangle.
   @param    r       Array of 4 integers as [xmin,xmax,ymin,ymax]
   @param    np      Number of points to generate.
@@ -706,6 +708,7 @@ cpl_bivector_gen_rect_poisson(const cpl_size *r,
 
 /*----------------------------------------------------------------------------*/
 /**
+  @internal
   @brief    Generate points with a Poisson scattering property in a ring.
   @param    r       Array of 4 doubles as [x,y,r1,r2]
   @param    np      Number of points to generate.
