@@ -43,19 +43,20 @@
 
  */
 /*----------------------------------------------------------------------------*/
-static void CPL_TYPE_ADD(cpl_geom_ima_offset_xcorr_subw)(double *correl,
-                                                         const cpl_image *im1,
-                                                         const cpl_image *im2,
-                                                         cpl_size x_1,
-                                                         cpl_size y_1,
-                                                         cpl_size x_2,
-                                                         cpl_size y_2,
-                                                         cpl_size s_hx,
-                                                         cpl_size s_hy,
-                                                         cpl_size m_hx,
-                                                         cpl_size m_hy,
-                                                         cpl_size *pk_min,
-                                                         cpl_size *pl_min)
+static void
+CPL_TYPE_ADD(cpl_geom_ima_offset_xcorr_subw)(double *correl,
+                                             const cpl_image *im1,
+                                             const cpl_image *im2,
+                                             cpl_size x_1,
+                                             cpl_size y_1,
+                                             cpl_size x_2,
+                                             cpl_size y_2,
+                                             cpl_size s_hx,
+                                             cpl_size s_hy,
+                                             cpl_size m_hx,
+                                             cpl_size m_hy,
+                                             cpl_size *pk_min,
+                                             cpl_size *pl_min)
 
 {
     double sqsum_min = DBL_MAX;
@@ -165,17 +166,18 @@ static void CPL_TYPE_ADD(cpl_geom_ima_offset_xcorr_subw)(double *correl,
 
  */
 /*----------------------------------------------------------------------------*/
-static void CPL_TYPE_ADD(cpl_geom_img_offset_saa)(cpl_image *final,
-                                                  cpl_image *contrib,
-                                                  cpl_size rmin,
-                                                  cpl_size rmax,
-                                                  double start_x,
-                                                  double start_y,
-                                                  const cpl_imagelist *ilist,
-                                                  cpl_size firstbpm,
-                                                  const cpl_bivector *offs,
-                                                  const cpl_vector *xyprofile,
-                                                  cpl_size tabsperpix)
+static void
+CPL_TYPE_ADD(cpl_geom_img_offset_saa)(cpl_image *final,
+                                      cpl_image *contrib,
+                                      cpl_size rmin,
+                                      cpl_size rmax,
+                                      double start_x,
+                                      double start_y,
+                                      const cpl_imagelist *ilist,
+                                      cpl_size firstbpm,
+                                      const cpl_bivector *offs,
+                                      const cpl_vector *xyprofile,
+                                      cpl_size tabsperpix)
 
 {
     const cpl_size nima = cpl_imagelist_get_size(ilist);
@@ -429,14 +431,14 @@ static void CPL_TYPE_ADD(cpl_geom_img_offset_saa)(cpl_image *final,
  */
 /*----------------------------------------------------------------------------*/
 static void
-    CPL_TYPE_ADD(cpl_geom_img_offset_saa_all)(cpl_image *final,
-                                              cpl_image *contrib,
-                                              double start_x,
-                                              double start_y,
-                                              const cpl_imagelist *ilist,
-                                              const cpl_bivector *offs,
-                                              const cpl_vector *xyprofile,
-                                              cpl_size tabsperpix)
+CPL_TYPE_ADD(cpl_geom_img_offset_saa_all)(cpl_image *final,
+                                          cpl_image *contrib,
+                                          double start_x,
+                                          double start_y,
+                                          const cpl_imagelist *ilist,
+                                          const cpl_bivector *offs,
+                                          const cpl_vector *xyprofile,
+                                          cpl_size tabsperpix)
 
 {
     const cpl_size nima = cpl_imagelist_get_size(ilist);
