@@ -1604,12 +1604,17 @@ cpl_fit_imagelist_polynomial_window_test(const cpl_vector *x_pos,
                 ? 0.0
                 : (pixeltype == CPL_TYPE_FLOAT
 #if defined SIZEOF_SIZE_T && SIZEOF_SIZE_T == 4
-                       /* FIXME: Extreme loss of precision on (some) 32-bit machines */
+                       /* Even with a wider long double (per configure)
+                          (some) 32-bit machines act as if their double and
+                          long double have same width */
                        ? 0.004
                        : 30.0 * FLT_EPSILON
-#else
+#elif defined HAVE_LONG_DOUBLE_WIDER
                        ? FLT_EPSILON
                        : 800.0 * DBL_EPSILON
+#else
+                       ? 0.006
+                       : 30.0 * FLT_EPSILON
 #endif
                   );
         cpl_error_code error;
