@@ -1,6 +1,6 @@
 /*
  * This file is part of the ESO Common Pipeline Library
- * Copyright (C) 2001-2017 European Southern Observatory
+ * Copyright (C) 2001-2022 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <cxmemory.h>
@@ -66,19 +66,22 @@
 typedef struct _cpl_frame_attributes_ cpl_frame_attributes;
 typedef struct _cpl_frame_fileinfo_ cpl_frame_fileinfo;
 
-struct _cpl_frame_attributes_ {
+struct _cpl_frame_attributes_
+{
     cpl_frame_type type;
     cpl_frame_group group;
     cpl_frame_level level;
 };
 
 
-struct _cpl_frame_fileinfo_ {
+struct _cpl_frame_fileinfo_
+{
     cxchar *name;
 };
 
 
-struct _cpl_frame_ {
+struct _cpl_frame_
+{
     cpl_frame_attributes attributes;
     cpl_frame_fileinfo *fileinfo;
     cxchar *tag;
@@ -92,20 +95,17 @@ struct _cpl_frame_ {
 inline static cpl_frame_fileinfo *
 _cpl_frame_fileinfo_new(void)
 {
-
     cpl_frame_fileinfo *info = cx_malloc(sizeof *info);
 
     info->name = NULL;
 
     return info;
-
 }
 
 
 inline static void
 _cpl_frame_fileinfo_delete(cpl_frame_fileinfo *info)
 {
-
     if (info->name) {
         cx_free(info->name);
     }
@@ -131,13 +131,13 @@ _cpl_frame_fileinfo_delete(cpl_frame_fileinfo *info)
 cpl_size
 cpl_frame_get_nplanes(const cpl_frame *self, cpl_size extnum)
 {
-    cpl_size         next;
-    cpl_size         nplanes;
-    cxint            naxis;
+    cpl_size next;
+    cpl_size nplanes;
+    cxint naxis;
     cxint status = 0;
     cxint hdu_type = ANY_HDU;
     cxint hdu_position = extnum + 1;
-    fitsfile  *file = NULL;
+    fitsfile *file = NULL;
 
     if (self == NULL) {
         cpl_error_set_(CPL_ERROR_NULL_INPUT);
@@ -164,16 +164,13 @@ cpl_frame_get_nplanes(const cpl_frame *self, cpl_size extnum)
         cpl_io_fits_close_file(file, &status);
         cpl_error_set_(CPL_ERROR_FILE_IO);
         return -1;
-
     }
     else {
-
         if (status != 0) {
             status = 0;
             cpl_io_fits_close_file(file, &status);
             cpl_error_set_(CPL_ERROR_BAD_FILE_FORMAT);
             return -1;
-
         }
     }
 
@@ -185,7 +182,6 @@ cpl_frame_get_nplanes(const cpl_frame *self, cpl_size extnum)
         cpl_error_set_(CPL_ERROR_DATA_NOT_FOUND);
 
         return -1;
-
     }
 
     /* Find the number of axes  */
@@ -210,7 +206,7 @@ cpl_frame_get_nplanes(const cpl_frame *self, cpl_size extnum)
         CPL_FITSIO_TYPE *naxes = cx_malloc(naxis * sizeof(CPL_FITSIO_TYPE));
         CPL_FITSIO_GET_SIZE(file, naxis, naxes, &status);
         nplanes = (cpl_size)naxes[2];
-        if(naxes[2] < 1)
+        if (naxes[2] < 1)
             nplanes = 0;
 
         cx_free(naxes);
@@ -220,7 +216,6 @@ cpl_frame_get_nplanes(const cpl_frame *self, cpl_size extnum)
     cx_assert(status == 0);
 
     return nplanes;
-
 }
 
 /*
@@ -285,8 +280,6 @@ cpl_frame_new(void)
 cpl_frame *
 cpl_frame_duplicate(const cpl_frame *other)
 {
-
-
     cpl_frame *copy;
 
 
@@ -302,7 +295,6 @@ cpl_frame_duplicate(const cpl_frame *other)
     }
 
     if (other->fileinfo) {
-
         copy->fileinfo = cx_malloc(sizeof(cpl_frame_fileinfo));
 
         if (other->fileinfo->name) {
@@ -311,7 +303,6 @@ cpl_frame_duplicate(const cpl_frame *other)
         else {
             copy->fileinfo->name = NULL;
         }
-
     }
 
     copy->attributes.type = other->attributes.type;
@@ -320,7 +311,6 @@ cpl_frame_duplicate(const cpl_frame *other)
 
 
     return copy;
-
 }
 
 
@@ -339,7 +329,6 @@ cpl_frame_duplicate(const cpl_frame *other)
 void
 cpl_frame_delete(cpl_frame *self)
 {
-
     if (self) {
         if (self->tag) {
             cx_free(self->tag);
@@ -353,7 +342,6 @@ cpl_frame_delete(cpl_frame *self)
     }
 
     return;
-
 }
 
 
@@ -393,9 +381,6 @@ cpl_frame_delete(cpl_frame *self)
 const char *
 cpl_frame_get_filename(const cpl_frame *self)
 {
-
-
-
     if (self == NULL) {
         cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
@@ -409,11 +394,9 @@ cpl_frame_get_filename(const cpl_frame *self)
     cx_assert(self->fileinfo->name != NULL);
 
     return self->fileinfo->name;
-
 }
 
 
-
 /**
  * @brief
  *   Get the category tag of a frame.
@@ -442,16 +425,12 @@ cpl_frame_get_filename(const cpl_frame *self)
 const char *
 cpl_frame_get_tag(const cpl_frame *self)
 {
-
-
-
     if (self == NULL) {
         cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return NULL;
     }
 
     return self->tag;
-
 }
 
 
@@ -483,16 +462,12 @@ cpl_frame_get_tag(const cpl_frame *self)
 cpl_frame_type
 cpl_frame_get_type(const cpl_frame *self)
 {
-
-
-
     if (self == NULL) {
         cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return CPL_FRAME_TYPE_NONE;
     }
 
     return self->attributes.type;
-
 }
 
 
@@ -523,16 +498,12 @@ cpl_frame_get_type(const cpl_frame *self)
 cpl_frame_group
 cpl_frame_get_group(const cpl_frame *self)
 {
-
-
-
     if (self == NULL) {
         cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return CPL_FRAME_GROUP_NONE;
     }
 
     return self->attributes.group;
-
 }
 
 
@@ -563,16 +534,12 @@ cpl_frame_get_group(const cpl_frame *self)
 cpl_frame_level
 cpl_frame_get_level(const cpl_frame *self)
 {
-
-
-
     if (self == NULL) {
         cpl_error_set_(CPL_ERROR_NULL_INPUT);
         return CPL_FRAME_LEVEL_NONE;
     }
 
     return self->attributes.level;
-
 }
 
 
@@ -608,8 +575,6 @@ cpl_frame_get_level(const cpl_frame *self)
 cpl_error_code
 cpl_frame_set_filename(cpl_frame *self, const char *filename)
 {
-
-
     cpl_frame_fileinfo *info;
 
 
@@ -632,7 +597,6 @@ cpl_frame_set_filename(cpl_frame *self, const char *filename)
     info->name = cx_strdup(filename);
 
     return CPL_ERROR_NONE;
-
 }
 
 
@@ -667,9 +631,6 @@ cpl_frame_set_filename(cpl_frame *self, const char *filename)
 cpl_error_code
 cpl_frame_set_tag(cpl_frame *self, const char *tag)
 {
-
-
-
     if (self == NULL || tag == NULL) {
         return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
@@ -682,7 +643,6 @@ cpl_frame_set_tag(cpl_frame *self, const char *tag)
     self->tag = cx_strdup(tag);
 
     return CPL_ERROR_NONE;
-
 }
 
 
@@ -714,16 +674,12 @@ cpl_frame_set_tag(cpl_frame *self, const char *tag)
 cpl_error_code
 cpl_frame_set_type(cpl_frame *self, cpl_frame_type type)
 {
-
-
-
     if (self == NULL) {
         return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     self->attributes.type = type;
     return CPL_ERROR_NONE;
-
 }
 
 
@@ -755,16 +711,12 @@ cpl_frame_set_type(cpl_frame *self, cpl_frame_type type)
 cpl_error_code
 cpl_frame_set_group(cpl_frame *self, cpl_frame_group group)
 {
-
-
-
     if (self == NULL) {
         return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     self->attributes.group = group;
     return CPL_ERROR_NONE;
-
 }
 
 
@@ -796,16 +748,12 @@ cpl_frame_set_group(cpl_frame *self, cpl_frame_group group)
 cpl_error_code
 cpl_frame_set_level(cpl_frame *self, cpl_frame_level level)
 {
-
-
-
     if (self == NULL) {
         return cpl_error_set_(CPL_ERROR_NULL_INPUT);
     }
 
     self->attributes.level = level;
     return CPL_ERROR_NONE;
-
 }
 
 /**
@@ -852,11 +800,10 @@ cpl_frame_get_nextensions(const cpl_frame *self)
         return -1;
     }
 
-    if((next = cpl_fits_count_extensions(self->fileinfo->name)) == -1)
+    if ((next = cpl_fits_count_extensions(self->fileinfo->name)) == -1)
         return -1;
 
     return next;
-
 }
 
 
@@ -877,7 +824,6 @@ cpl_frame_get_nextensions(const cpl_frame *self)
 void
 cpl_frame_dump(const cpl_frame *frame, FILE *stream)
 {
-
     const char *name;
     const char *tag;
 
@@ -899,38 +845,38 @@ cpl_frame_dump(const cpl_frame *frame, FILE *stream)
     group = cpl_frame_get_group(frame);
     level = cpl_frame_get_level(frame);
 
-    fprintf(stream, "%s  \t%s  ",name, tag);
+    fprintf(stream, "%s  \t%s  ", name, tag);
 
     switch (type) {
         case CPL_FRAME_TYPE_IMAGE:
-            fprintf(stream, "%s  ","CPL_FRAME_TYPE_IMAGE");
+            fprintf(stream, "%s  ", "CPL_FRAME_TYPE_IMAGE");
             break;
 
         case CPL_FRAME_TYPE_MATRIX:
-            fprintf(stream, "%s  ","CPL_FRAME_TYPE_MATRIX");
+            fprintf(stream, "%s  ", "CPL_FRAME_TYPE_MATRIX");
             break;
 
         case CPL_FRAME_TYPE_TABLE:
-            fprintf(stream, "%s  ","CPL_FRAME_TYPE_TABLE");
+            fprintf(stream, "%s  ", "CPL_FRAME_TYPE_TABLE");
             break;
 
         case CPL_FRAME_TYPE_PAF:
-            fprintf(stream, "%s  ","CPL_FRAME_TYPE_PAF");
+            fprintf(stream, "%s  ", "CPL_FRAME_TYPE_PAF");
             break;
 
         case CPL_FRAME_TYPE_ANY:
-            fprintf(stream, "%s  ","CPL_FRAME_TYPE_ANY");
+            fprintf(stream, "%s  ", "CPL_FRAME_TYPE_ANY");
             break;
 
         default:
-            fprintf(stream, "%s  ","CPL_FRAME_TYPE_NONE");
+            fprintf(stream, "%s  ", "CPL_FRAME_TYPE_NONE");
             break;
     }
 
 
     switch (group) {
         case CPL_FRAME_GROUP_RAW:
-            fprintf(stream, "%s  ","CPL_FRAME_GROUP_RAW");
+            fprintf(stream, "%s  ", "CPL_FRAME_GROUP_RAW");
             break;
 
         case CPL_FRAME_GROUP_CALIB:
@@ -942,18 +888,18 @@ cpl_frame_dump(const cpl_frame *frame, FILE *stream)
             break;
 
         default:
-            fprintf(stream, "%s  ","CPL_FRAME_GROUP_NONE");
+            fprintf(stream, "%s  ", "CPL_FRAME_GROUP_NONE");
             break;
     }
 
 
     switch (level) {
         case CPL_FRAME_LEVEL_TEMPORARY:
-            fprintf(stream, "%s  ","CPL_FRAME_LEVEL_TEMPORARY");
+            fprintf(stream, "%s  ", "CPL_FRAME_LEVEL_TEMPORARY");
             break;
 
         case CPL_FRAME_LEVEL_INTERMEDIATE:
-            fprintf(stream, "%s  ","CPL_FRAME_LEVEL_INTERMEDIATE");
+            fprintf(stream, "%s  ", "CPL_FRAME_LEVEL_INTERMEDIATE");
             break;
 
         case CPL_FRAME_LEVEL_FINAL:
@@ -961,15 +907,13 @@ cpl_frame_dump(const cpl_frame *frame, FILE *stream)
             break;
 
         default:
-            fprintf(stream, "%s  ","CPL_FRAME_LEVEL_NONE");
+            fprintf(stream, "%s  ", "CPL_FRAME_LEVEL_NONE");
             break;
-
     }
 
     fprintf(stream, "\n");
 
     return;
-
 }
 
 
