@@ -113,6 +113,7 @@
  *      HAVE_STDDEF_H
  *      HAVE_STDINT_H
  *      HAVE_STDLIB_H
+ *      HAVE_FLOAT_H
  *      HAVE_INTTYPES_H
  *      HAVE_LOCALE_H
  *      HAVE_LOCALECONV
@@ -162,8 +163,8 @@
  * <http://www.jhweiss.de/software/snprintf.html>.
  */
 
-#if HAVE_CONFIG_H
-#  include <config.h>
+#ifdef HAVE_CONFIG_H
+#include <config.h>
 #endif
 
 
@@ -187,7 +188,7 @@
 #elif defined(__linux__)
 #define OS_LINUX 1
 #endif  /* defined(__NetBSD__) || defined(__FreeBSD__) || [...] */
-#if HAVE_CONFIG_H   /* Undefine definitions possibly done in config.h. */
+#ifdef HAVE_CONFIG_H    /* Undefine definitions possibly done in config.h. */
 #ifdef HAVE_SNPRINTF
 #undef HAVE_SNPRINTF
 #endif  /* defined(HAVE_SNPRINTF) */
@@ -225,6 +226,9 @@
 #ifndef HAVE_STDLIB_H
 #define HAVE_STDLIB_H 1
 #endif  /* HAVE_STDLIB_H */
+#ifndef HAVE_FLOAT_H
+#define HAVE_FLOAT_H 1
+#endif  /* HAVE_FLOAT_H */
 #ifndef HAVE_INTTYPES_H
 #define HAVE_INTTYPES_H 1
 #endif  /* HAVE_INTTYPES_H */
@@ -322,6 +326,9 @@ static void *mymemcpy(void *, void *, size_t);
 #if !defined(HAVE_VSNPRINTF)
 #include <errno.h>  /* For ERANGE and errno. */
 #include <limits.h> /* For *_MAX. */
+#ifdef HAVE_FLOAT_H
+#include <float.h>  /* For *DBL_{MIN,MAX}_10_EXP. */
+#endif  /* HAVE_FLOAT_H */
 #ifdef HAVE_INTTYPES_H
 #include <inttypes.h>   /* For intmax_t (if not defined in <stdint.h>). */
 #endif  /* HAVE_INTTYPES_H */
@@ -380,8 +387,12 @@ static void *mymemcpy(void *, void *, size_t);
 #ifndef LDOUBLE
 #ifdef HAVE_LONG_DOUBLE
 #define LDOUBLE long double
+#define LDOUBLE_MIN_10_EXP LDBL_MIN_10_EXP
+#define LDOUBLE_MAX_10_EXP LDBL_MAX_10_EXP
 #else
 #define LDOUBLE double
+#define LDOUBLE_MIN_10_EXP DBL_MIN_10_EXP
+#define LDOUBLE_MAX_10_EXP DBL_MAX_10_EXP
 #endif  /* HAVE_LONG_DOUBLE */
 #endif  /* !defined(LDOUBLE) */
 
@@ -500,7 +511,7 @@ static void *mymemcpy(void *, void *, size_t);
 #define ISNAN(x) (x != x)
 #endif  /* !defined(ISNAN) */
 #ifndef ISINF
-#define ISINF(x) (x != 0.0 && x + x == x)
+#define ISINF(x) ((x < -1 || x > 1) && x + x == x)
 #endif  /* !defined(ISINF) */
 
 #ifdef OUTCHAR
@@ -776,11 +787,28 @@ rpl_vsnprintf(char *str, size_t size, const char *format, va_list args)
             case 'A':
                 /* Not yet supported, we'll use "%F". */
                 /* FALLTHROUGH */
+            case 'E':
+                if (ch == 'E')
+                    flags |= PRINT_F_TYPE_E;
+                /* FALLTHROUGH */
+            case 'G':
+                if (ch == 'G')
+                    flags |= PRINT_F_TYPE_G;
+                /* FALLTHROUGH */
             case 'F':
                 flags |= PRINT_F_UP;
+                /* FALLTHROUGH */
             case 'a':
                 /* Not yet supported, we'll use "%f". */
                 /* FALLTHROUGH */
+            case 'e':
+                if (ch == 'e')
+                    flags |= PRINT_F_TYPE_E;
+                /* FALLTHROUGH */
+            case 'g':
+                if (ch == 'g')
+                    flags |= PRINT_F_TYPE_G;
+                /* FALLTHROUGH */
             case 'f':
                 if (cflags == PRINT_C_LDOUBLE)
                     fvalue = va_arg(args, LDOUBLE);
@@ -791,40 +819,6 @@ rpl_vsnprintf(char *str, size_t size, const char *format, va_list args)
                 if (overflow)
                     goto out;
                 break;
-            case 'E':
-                flags |= PRINT_F_UP;
-                /* FALLTHROUGH */
-            case 'e':
-                flags |= PRINT_F_TYPE_E;
-                if (cflags == PRINT_C_LDOUBLE)
-                    fvalue = va_arg(args, LDOUBLE);
-                else
-                    fvalue = va_arg(args, double);
-                fmtflt(str, &len, size, fvalue, width,
-                    precision, flags, &overflow);
-                if (overflow)
-                    goto out;
-                break;
-            case 'G':
-                flags |= PRINT_F_UP;
-                /* FALLTHROUGH */
-            case 'g':
-                flags |= PRINT_F_TYPE_G;
-                if (cflags == PRINT_C_LDOUBLE)
-                    fvalue = va_arg(args, LDOUBLE);
-                else
-                    fvalue = va_arg(args, double);
-                /*
-                 * If the precision is zero, it is treated as
-                 * one (cf. C99: 7.19.6.1, 8).
-                 */
-                if (precision == 0)
-                    precision = 1;
-                fmtflt(str, &len, size, fvalue, width,
-                    precision, flags, &overflow);
-                if (overflow)
-                    goto out;
-                break;
             case 'c':
                 cvalue = va_arg(args, int);
                 OUTCHAR(str, len, size, cvalue);
@@ -922,8 +916,8 @@ out:
     else if (size > 0)
         str[size - 1] = '\0';
 
-    if (overflow || len >= INT_MAX) {
-        errno = overflow ? EOVERFLOW : ERANGE;
+    if (overflow || len > INT_MAX) {
+        errno = EOVERFLOW;
         return -1;
     }
     return (int)len;
@@ -940,8 +934,8 @@ fmtstr(char *str, size_t *len, size_t size, const char *value, int width,
         value = "(null)";
 
     /* If a precision was specified, don't read the string past it. */
-    for (strln = 0; value[strln] != '\0' &&
-        (noprecision || strln < precision); strln++)
+    for (strln = 0; (noprecision || strln < precision) &&
+        value[strln] != '\0'; strln++)
         continue;
 
     if ((padlen = width - strln) < 0)
@@ -953,7 +947,7 @@ fmtstr(char *str, size_t *len, size_t size, const char *value, int width,
         OUTCHAR(str, *len, size, ' ');
         padlen--;
     }
-    while (*value != '\0' && (noprecision || precision-- > 0)) {
+    while ((noprecision || precision-- > 0) && *value != '\0') {
         OUTCHAR(str, *len, size, *value);
         value++;
     }
@@ -1075,7 +1069,7 @@ fmtflt(char *str, size_t *len, size_t size, LDOUBLE fvalue, int width,
     const char *infnan = NULL;
     char iconvert[MAX_CONVERT_LENGTH];
     char fconvert[MAX_CONVERT_LENGTH];
-    char econvert[4];   /* "e-12" (without nul-termination). */
+    char econvert[5];   /* "e-300" (without nul-termination). */
     char esign = 0;
     char sign = 0;
     int leadfraczeros = 0;
@@ -1118,6 +1112,7 @@ fmtflt(char *str, size_t *len, size_t size, LDOUBLE fvalue, int width,
             iconvert[ipos++] = sign;
         while (*infnan != '\0')
             iconvert[ipos++] = *infnan++;
+        iconvert[ipos++] = '\0';
         fmtstr(str, len, size, iconvert, width, ipos, flags);
         return;
     }
@@ -1125,6 +1120,12 @@ fmtflt(char *str, size_t *len, size_t size, LDOUBLE fvalue, int width,
     /* "%e" (or "%E") or "%g" (or "%G") conversion. */
     if (flags & PRINT_F_TYPE_E || flags & PRINT_F_TYPE_G) {
         if (flags & PRINT_F_TYPE_G) {
+            /*
+             * If the precision is zero, it is treated as one (cf.
+             * C99: 7.19.6.1, 8).
+             */
+            if (precision == 0)
+                precision = 1;
             /*
              * For "%g" (and "%G") conversions, the precision
              * specifies the number of significant digits, which
@@ -1244,12 +1245,12 @@ again:
             esign = '+';
 
         /*
-         * Convert the exponent.  The sizeof(econvert) is 4.  So, the
-         * econvert buffer can hold e.g. "e+99" and "e-99".  We don't
-         * support an exponent which contains more than two digits.
+         * Convert the exponent.  The sizeof(econvert) is 5.  So, the
+         * econvert buffer can hold e.g. "e+999" and "e-999".  We don't
+         * support an exponent which contains more than three digits.
          * Therefore, the following stores are safe.
          */
-        epos = convert(exponent, econvert, 2, 10, 0);
+        epos = convert(exponent, econvert, 3, 10, 0);
         /*
          * C99 says: "The exponent always contains at least two digits,
          * and only as many more digits as necessary to represent the
@@ -1393,15 +1394,15 @@ getexponent(LDOUBLE value)
     int exponent = 0;
 
     /*
-     * We check for 99 > exponent > -99 in order to work around possible
-     * endless loops which could happen (at least) in the second loop (at
-     * least) if we're called with an infinite value.  However, we checked
-     * for infinity before calling this function using our ISINF() macro, so
-     * this might be somewhat paranoid.
+     * We check for LDOUBLE_MAX_10_EXP >= exponent >= LDOUBLE_MIN_10_EXP in
+     * order to work around possible endless loops which could happen (at
+     * least) in the second loop (at least) if we're called with an infinite
+     * value.  However, we checked for infinity before calling this function
+     * using our ISINF() macro, so this might be somewhat paranoid.
      */
-    while (tmp < 1.0 && tmp > 0.0 && --exponent > -99)
+    while (tmp < 1.0 && tmp > 0.0 && --exponent >= LDOUBLE_MIN_10_EXP)
         tmp *= 10;
-    while (tmp >= 10.0 && ++exponent < 99)
+    while (tmp >= 10.0 && ++exponent <= LDOUBLE_MAX_10_EXP)
         tmp /= 10;
 
     return exponent;
@@ -1434,7 +1435,7 @@ cast(LDOUBLE value)
      * comparison (cf. C99: 6.3.1.4, 2).  It might then equal the LDOUBLE
      * value although converting the latter to UINTMAX_T would overflow.
      */
-    if (value >= UINTMAX_MAX)
+    if (value >= (LDOUBLE)UINTMAX_MAX)
         return UINTMAX_MAX;
 
     result = value;
@@ -1451,6 +1452,9 @@ myround(LDOUBLE value)
 {
     UINTMAX_T intpart = cast(value);
 
+    if (intpart == UINTMAX_MAX)
+        return UINTMAX_MAX;
+    
     return ((value -= intpart) < 0.5) ? intpart : intpart + 1;
 }
 
@@ -1554,7 +1558,7 @@ rpl_asprintf(va_alist) va_dcl
 }
 #endif  /* !HAVE_ASPRINTF */
 #else   /* Dummy declaration to avoid empty translation unit warnings. */
-int main(void);
+int main(int argc, char **argv);
 #endif  /* !HAVE_SNPRINTF || !HAVE_VSNPRINTF || !HAVE_ASPRINTF || [...] */
 
 #if defined(TEST_SNPRINTF)
@@ -2049,22 +2053,22 @@ main(void)
 #ifdef TEST
 #undef TEST
 #endif  /* defined(TEST) */
-#define TEST(fmt, val)                                             \
-do {                                                               \
-    for (i = 0; fmt[i] != NULL; i++)                               \
-        for (j = 0; j == 0 || val[j - TEST_NILS] != 0; j++) {      \
+#define TEST(fmt, val)                                                         \
+do {                                                                           \
+    for (i = 0; fmt[i] != NULL; i++)                                       \
+        for (j = 0; j == 0 || val[j - TEST_NILS] != 0; j++) {          \
             r1 = sprintf(buf1, fmt[i], val[j]);                    \
             r2 = snprintf(buf2, sizeof(buf2), fmt[i], val[j]);     \
             if (strcmp(buf1, buf2) != 0 || r1 != r2) {             \
-                (void)printf("Results don't match, "               \
-                    "format string: %s\n"                          \
-                    "\t sprintf(3): [%s] (%d)\n"                   \
-                    "\tsnprintf(3): [%s] (%d)\n",                  \
-                    fmt[i], buf1, r1, buf2, r2);                   \
-                failed++;                                          \
+                (void)printf("Results don't match, "           \
+                    "format string: %s\n"                      \
+                    "\t sprintf(3): [%s] (%d)\n"               \
+                    "\tsnprintf(3): [%s] (%d)\n",              \
+                    fmt[i], buf1, r1, buf2, r2);               \
+                failed++;                                      \
             }                                                      \
             num++;                                                 \
-        }                                                          \
+        }                                                              \
 } while (/* CONSTCOND */ 0)
 
 #ifdef HAVE_LOCALE_H
@@ -2092,8 +2096,9 @@ do {                                                               \
             break;
         }
     }
+    (void)printf("apparently %d.\n", i);
     return (failed == 0) ? 0 : 1;
 }
 #endif  /* TEST_SNPRINTF */
 
-/* vim: set joinspaces textwidth=80: */
+/* vim: set joinspaces expandtab textwidth=80 cinoptions=(4,u0: */
